<?php

/*
 * by
 * Deepshikha Jain
 */
class OrdersController extends AppController {


######################### usaepay start ######################################################
	
	// Required for all transactions
	var $key;			// Source key
	var $pin;			// Source pin (optional)
	var $amount;		// the entire amount that will be charged to the customers card 
							// (including tax, shipping, etc)
	var $invoice;		// invoice number.  must be unique.  limited to 10 digits.  use orderid if you need longer. 
	
	// Required for Level 2 - Commercial Card support
	var $ponum;			// Purchase Order Number
	var $tax;			// Tax
	var $nontaxable;	// Order is non taxable
	var $digitalgoods; //digital goods indicator (ecommerce)
	
	// Level 3 support
	var $duty;
	var $shipfromzip;
	
	// Amount details (optional)
	var $tip; 			// Tip
	var $shipping;		// Shipping charge
	var $discount; 	// Discount amount (ie gift certificate or coupon code)
	var $subtotal; 	// if subtotal is set, then 
							// subtotal + tip + shipping - discount + tax must equal amount 
							// or the transaction will be declined.  If subtotal is left blank
							// then it will be ignored
	var $currency;		// Currency of $amount
	var $allowpartialauth; //set to true if a partial authorization (less than the full $amount)  will be accepted
		
	// Required Fields for Card Not Present transacitons (Ecommerce)
	var $card;			// card number, no dashes, no spaces
	var $exp;			// expiration date 4 digits no /
	var $cardholder; 	// name of card holder
	var $street;		// street address
	var $zip;			// zip code
	
	// Fields for Card Present (POS) 
	var $magstripe;  	// mag stripe data.  can be either Track 1, Track2  or  Both  (Required if card,exp,cardholder,street and zip aren't filled in)
	var $cardpresent;   // Must be set to true if processing a card present transaction  (Default is false)
	var $termtype;  	// The type of terminal being used:  Optons are  POS - cash register, StandAlone - self service terminal,  Unattended - ie gas pump, Unkown  (Default:  Unknown)
	var $magsupport;  	// Support for mag stripe reader:   yes, no, contactless, unknown  (default is unknown unless magstripe has been sent)
	var $contactless;  	// Magstripe was read with contactless reader:  yes, no  (default is no)
	var $dukpt;			// DUK/PT for PIN Debit
	var $signature;     // Signature Capture data
		
	// fields required for check transactions
	var $account;		// bank account number
	var $routing;		// bank routing number
	var $ssn;			// social security number
	var $dlnum;			// drivers license number (required if not using ssn)
	var $dlstate;		// drivers license issuing state
	var $checknum;		// Check Number
	var $accounttype;       // Checking or Savings
	var $checkformat;	// Override default check record format
	var $checkimage_front;    // Check front
	var $checkimage_back;		// Check back
	var $auxonus;
	var $epccode;
	var $micr;
	
	
	// Fields required for Secure Vault Payments (Direct Pay)
	var $svpbank;		// ID of cardholders bank
	var $svpreturnurl;	// URL that the bank should return the user to when tran is completed
	var $svpcancelurl; 	// URL that the bank should return the user if they cancel
	
	

	// Option parameters
	var $origauthcode;	// required if running postauth transaction.
	var $command;		// type of command to run; Possible values are: 
						// sale, credit, void, preauth, postauth, check and checkcredit. 
						// Default is sale.
	var $orderid;		// Unique order identifier.  This field can be used to reference 
						// the order for which this transaction corresponds to. This field 
						// can contain up to 64 characters and should be used instead of 
						// UMinvoice when orderids longer that 10 digits are needed.
	var $custid;   // Alpha-numeric id that uniquely identifies the customer.
	var $description;	// description of charge
	var $cvv2;			// cvv2 code
	var $custemail;		// customers email address
	var $custreceipt;	// send customer a receipt
	var $custreceiptname;	// name of custom receipt template
	var $ignoreduplicate; // prevent the system from detecting and folding duplicates
	var $ip;			// ip address of remote host
	var $testmode;		// test transaction but don't process it
	var $usesandbox;    // use sandbox server instead of production
	var $timeout;       // transaction timeout.  defaults to 45 seconds
	var $gatewayurl;   	// url for the gateway
	var $proxyurl;		// proxy server to use (if required by network)
	var $ignoresslcerterrors;  // Bypasses ssl certificate errors.  It is highly recommended that you do not use this option.  Fix your openssl installation instead!
	var $cabundle;      // manually specify location of root ca bundle (useful of root ca is not in default location)
	var $transport;     // manually select transport to use (curl or stream), by default the library will auto select based on what is available
	var $clerk;					// Indicates the clerk/person processing transaction, for reporting purposes. (optional)
	var $terminal;				// Indiactes the terminal used to process transaction, for reporting purposes. (optional)
	var $restaurant_table;	// Indicates the restaurant table, for reporting purposes. (optional)
	var $ticketedevent;  // ID of Event when doing a ticket sale
	var $ifauthexpired;  // controls what happens when capturing an authorization that has expire.  options are 'ignore','error','reauth'.
	var $authexpiredays;  //set the number of days an authorization is valid for.  defaults to merchant account setting.
	var $inventorylocation; // set the warehouse to pull inventory from.  defaults to source key setting.
	
	// Card Authorization - Verified By Visa and Mastercard SecureCode
	var $cardauth;    	// enable card authentication
	var $pares; 		// 
	
	// Third Party Card Authorization
	var $xid;
	var $cavv;
	var $eci;

	// Customer Database
	var $addcustomer;		//  Save transaction as a recurring transaction:  yes/no
	var $recurring;		// (obsolete,  see the addcustomer)
	
	var $schedule;		//  How often to run transaction: daily, weekly, biweekly, monthly, bimonthly, quarterly, annually.  Default is monthly, set to disabled if you don't want recurring billing
	var $numleft; 		//  The number of times to run. Either a number or * for unlimited.  Default is unlimited.
	var $start;			//  When to start the schedule.  Default is tomorrow.  Must be in YYYYMMDD  format.
	var $end;			//  When to stop running transactions. Default is to run forever.  If both end and numleft are specified, transaction will stop when the earliest condition is met.
	var $billamount;	//  Optional recurring billing amount.  If not specified, the amount field will be used for future recurring billing payments
	var $billtax;
	var $billsourcekey;
	
	// tokenization
	var $savecard;		// create a card token if the sale is approved, returns a cardref variable
	
	// Manually mark as recurring
	var $isrecurring;
	
	// Billing Fields
	var $billfname;
	var $billlname;
	var $billcompany;
	var $billstreet;
	var $billstreet2;
	var $billcity;
	var $billstate;
	var $billzip;
	var $billcountry;
	var $billphone;
	var $email;
	var $fax;
	var $website;

	// Shipping Fields
	var $delivery;		// type of delivery method ('ship','pickup','download')
	var $shipfname;
	var $shiplname;
	var $shipcompany;
	var $shipstreet;
	var $shipstreet2;
	var $shipcity;
	var $shipstate;
	var $shipzip;
	var $shipcountry;
	var $shipphone;
	
	// Custom Fields
	var $custom1;
	var $custom2;
	var $custom3;
	var $custom4;
	var $custom5;
	var $custom6;
	var $custom7;
	var $custom8;
	var $custom9;
	var $custom10;
	var $custom11;
	var $custom12;
	var $custom13;
	var $custom14;
	var $custom15;
	var $custom16;
	var $custom17;
	var $custom18;
	var $custom19;
	var $custom20;
	
	
	// Line items  (see addLine)
	var $lineitems;
	
	
	var $comments; // Additional transaction details or comments (free form text field supports up to 65,000 chars)
	
	var $software; // Allows developers to identify their application to the gateway (for troubleshooting purposes)
	
	// Fraud Profiling
	var $session;
	
	// response fields
	var $rawresult;		// raw result from gateway
	var $result;		// full result:  Approved, Declined, Error
	var $resultcode; 	// abreviated result code: A D E
	var $authcode;		// authorization code
	var $refnum;		// reference number
	var $batch;		// batch number
	var $avs_result;		// avs result
	var $avs_result_code;		// avs result
	var $avs;  					// obsolete avs result
	var $cvv2_result;		// cvv2 result
	var $cvv2_result_code;		// cvv2 result
	var $vpas_result_code;      // vpas result
	var $isduplicate;      // system identified transaction as a duplicate
	var $convertedamount;  // transaction amount after server has converted it to merchants currency
	var $convertedamountcurrency;  // merchants currency
	var $conversionrate;  // the conversion rate that was used
	var $custnum;  //  gateway assigned customer ref number for recurring billing
	var $authamount; // amount that was authorized
	var $balance;  //remaining balance
	var $cardlevelresult;
	var $procrefnum;
	var $cardref; 		// card number token
	
	// Cardinal Response Fields
	var $acsurl;	// card auth url
	var $pareq;		// card auth request
	var $cctransid; // cardinal transid
	
	// Fraud Profiler
	var $profiler_score;
	var $profiler_response;
	var $profiler_reason;
	
	// Errors Response Feilds
	var $error; 		// error message if result is an error
	var $errorcode; 	// numerical error code
	var $blank;			// blank response
	var $transporterror; 	// transport error
	
	
	// Constructor
	function umTransaction()
	{
		// Set default values.
		$this->command="sale";
		$this->result="Error";
		$this->resultcode="E";
		$this->error="Transaction not processed yet.";
		$this->timeout=45;
		$this->cardpresent=false;
		$this->lineitems = array();
		if(isset($_SERVER['REMOTE_ADDR'])) $this->ip=$_SERVER['REMOTE_ADDR'];
		$this->software="USAePay PHP API v" . USAEPAY_VERSION;

	}
	
	/**
	 * Add a line item to the transaction
	 *
	 * @param string $sku
	 * @param string $name
	 * @param string $description
	 * @param double $cost
	 * @param string $taxable
	 * @param int $qty
	 * @param string $refnum
	 */
	function addLine($sku, $name='', $description='', $cost='', $qty='', $taxable='', $refnum=0)
	{
		if(is_array($sku))
		{
			$vars = $sku;
			$this->lineitems[] = array(
						'sku' => @$vars['sku'],
						'name' => @$vars['name'],
						'description' => @$vars['description'],
						'cost' => @$vars['cost'],
						'taxable' => @$vars['taxable'],
						'qty' => @$vars['qty'],
						'refnum' => @$vars['refnum'],
						'um' => @$vars['um'],
						'taxrate' => @$vars['taxrate'],
						'taxamount' => @$vars['taxamount'],
						'taxclass' => @$vars['taxclass'],
						'commoditycode' => @$vars['commoditycode'],
						'discountrate' => @$vars['discountrate'],
						'discountamount' => @$vars['discountamount'],
					);
			
		} else {
			$this->lineitems[] = array(
					'sku' => $sku,
					'name' => $name,
					'description' => $description,
					'cost' => $cost,
					'taxable' => $taxable,
					'qty' => $qty,
					'refnum' => $refnum
				);
		}
	}

	function getLineTotal()
	{
		$total = 0;
		foreach($this->lineitems as $line)
		{
			$total+=(intval($line['cost']*100) * intval($line['qty']));
		}
		return number_format($total/100, 2, '.','');
	}
	
	/**
	 * Remove all line items
	 * 
	 */
	function clearLines()
	{
		$this->lineitems=array();		
	}
	
	/**
	 * Clear all transaction parameters except for the key and pin. Should be run between transactions if not 
	 * reinsantiating the umTransaction class
	 *
	 */
	function clearData()
	{
		$map =$this->getFieldMap();
		foreach($map as $apifield => $classfield)
		{
			if($classfield=='software' || $classfield=='key' || $classfield=='pin') continue;
			unset($this->$classfield);
		}
		
		// Set default values.
		$this->command="sale";
		$this->result="Error";
		$this->resultcode="E";
		$this->error="Transaction not processed yet.";
		$this->cardpresent=false;
		$this->lineitems = array();
		if(isset($_SERVER['REMOTE_ADDR'])) $this->ip=$_SERVER['REMOTE_ADDR'];
		
	}
	
	/**
	 * Verify that all required data has been set
	 *
	 * @return string
	 */
	function CheckData()
	{
		if(!$this->key) return "Source Key is required";
		if(in_array(strtolower($this->command), array("cc:capture", "cc:refund", "refund", "check:refund","capture", "creditvoid", 'quicksale', 'quickcredit','refund:adjust','void:release')))
		{
			if(!$this->refnum) return "Reference Number is required";		
		}else if(in_array(strtolower($this->command), array("svp")))
		{
			if(!$this->svpbank) return "Bank ID is required";		
			if(!$this->svpreturnurl) return "Return URL is required";		
			if(!$this->svpcancelurl) return "Cancel URL is required";		
		}  else {
			if(in_array(strtolower($this->command), array("check:sale","check:credit", "check", "checkcredit","reverseach") )) {
					if(!$this->account) return "Account Number is required";
					if(!$this->routing) return "Routing Number is required";
			} else if (in_array(strtolower($this->command) , array('cash','cash:refund','cash:sale','external:check:sale','external:cc:sale','external:gift:sale'))) {
				// nothing needs to be validated for cash 
			} else {
				if(!$this->magstripe) {
					if(!$this->card) return "Credit Card Number is required ({$this->command})";
					if(!$this->exp) return "Expiration Date is required";
				}
			}
			$this->amount=preg_replace("/[^0-9\.]/","",$this->amount);
			if(!$this->amount) return "Amount is required";
			if(!$this->invoice && !$this->orderid) return "Invoice number or Order ID is required";
			if(!$this->magstripe) {
				//if(!$this->cardholder) return "Cardholder Name is required";
				//if(!$this->street) return "Street Address is required";
				//if(!$this->zip) return "Zipcode is required";
			}
		}
		return 0;
	}
	
	/**
	 * Send transaction to the USAePay Gateway and parse response
	 *
	 * @return boolean
	 */
	function Process()
	{
		// check that we have the needed data
		$tmp=$this->CheckData();
		if($tmp)
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error=$tmp;
			$this->errorcode=10129;
			return false;
		}
		
		// populate the data
		$map = $this->getFieldMap();
		$data = array();
		foreach($map as $apifield =>$classfield)
		{
			switch($classfield)
			{
				case 'isrecurring':
					if($this->isrecurring) $data['UMisRecurring'] = 'Y';
					break;
				case 'nontaxable':
					if($this->nontaxable) $data['UMnontaxable'] = 'Y';
					break;
				case 'checkimage_front':
				case 'checkimage_back':
					$data[$apifield] = base64_encode($this->$classfield);
					break;
				case 'billsourcekey':
					if($this->billsourcekey) $data['UMbillsourcekey'] = 'yes';
					break;
				case 'cardpresent':
					if($this->cardpresent) $data['UMcardpresent'] = '1'; 
					break;
				case 'allowpartialauth':
					if($this->allowpartialauth===true) $data['UMallowPartialAuth'] = 'Yes';
					break;
				case 'savecard':
					if($this->savecard) $data['UMsaveCard'] = 'y';
					break;
				default: 
					$data[$apifield] = $this->$classfield;
			}
		}
		
		if(isset($data['UMcheckimagefront']) || isset($data['UMcheckimageback'])) $data['UMcheckimageencoding'] = 'base64';
		
		// tack on custom fields
		for($i=1; $i<=20; $i++)
		{
			if($this->{"custom$i"}) $data["UMcustom$i"] = $this->{"custom$i"};
		}
		
		// tack on line level detail
		$c=1;
		if(!is_array($this->lineitems)) $this->lineitems=array();
		foreach($this->lineitems as $lineitem)
		{
			$data["UMline{$c}sku"] = $lineitem['sku'];
			$data["UMline{$c}name"] = $lineitem['name'];
			$data["UMline{$c}description"] = $lineitem['description'];
			$data["UMline{$c}cost"] = $lineitem['cost'];
			$data["UMline{$c}taxable"] = $lineitem['taxable'];
			$data["UMline{$c}qty"] = $lineitem['qty'];
			if($lineitem['refnum']) 
				$data["UMline{$c}prodRefNum"] = $lineitem['refnum'];
			
			//optional level 3 data
			if($lineitem['um']) $data["UMline{$c}um"] = $lineitem['um'];
			if($lineitem['taxrate']) $data["UMline{$c}taxrate"] = $lineitem['taxrate'];
			if($lineitem['taxamount']) $data["UMline{$c}taxamount"] = $lineitem['taxamount'];
			if($lineitem['taxclass']) $data["UMline{$c}taxclass"] = $lineitem['taxclass'];
			if($lineitem['commoditycode']) $data["UMline{$c}commoditycode"] = $lineitem['commoditycode'];
			if($lineitem['discountrate']) $data["UMline{$c}discountrate"] = $lineitem['discountrate'];
			if($lineitem['discountamount']) $data["UMline{$c}discountamount"] = $lineitem['discountamount'];
			$c++;	
		}
				
		// Create hash if pin has been set.
		if(trim($this->pin))
		{
			// generate random seed value
			$seed = microtime(true) . rand();
			
			// assemble prehash data
			$prehash = $this->command . ":" . trim($this->pin) . ":" . $this->amount . ":" . $this->invoice . ":" . $seed;
			
			// if sha1 is available,  create sha1 hash,  else use md5
			if(function_exists('sha1')) $hash = 's/' . $seed . '/' . sha1($prehash) . '/n';
			else $hash = 'm/' . $seed . '/' . md5($prehash) . '/n';
			
			// populate hash value
			$data['UMhash'] = $hash;			
		}				
		
		// Figure out URL
		$url = ($this->gatewayurl?$this->gatewayurl:"https://www.usaepay.com/gate");
		if($this->usesandbox) $url = "https://sandbox.usaepay.com/gate";
			
		// Post data to Gateway
		$result=$this->httpPost($url, $data);
		if($result===false) return false;
		
		// result is in urlencoded format, parse into an array
		parse_str($result,$tmp);

		// check to make sure we received the correct fields
		if(!isset($tmp["UMversion"]) || !isset($tmp["UMstatus"]))
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error="Error parsing data from card processing gateway.";
			$this->errorcode=10132;
			return false;			
		}

		// Store results		
		$this->result=(isset($tmp["UMstatus"])?$tmp["UMstatus"]:"Error");	
		$this->resultcode=(isset($tmp["UMresult"])?$tmp["UMresult"]:"E");	
		$this->authcode=(isset($tmp["UMauthCode"])?$tmp["UMauthCode"]:"");
		$this->refnum=(isset($tmp["UMrefNum"])?$tmp["UMrefNum"]:"");
		$this->batch=(isset($tmp["UMbatch"])?$tmp["UMbatch"]:"");
		$this->avs_result=(isset($tmp["UMavsResult"])?$tmp["UMavsResult"]:"");
		$this->avs_result_code=(isset($tmp["UMavsResultCode"])?$tmp["UMavsResultCode"]:"");
		$this->cvv2_result=(isset($tmp["UMcvv2Result"])?$tmp["UMcvv2Result"]:"");
		$this->cvv2_result_code=(isset($tmp["UMcvv2ResultCode"])?$tmp["UMcvv2ResultCode"]:"");
		$this->vpas_result_code=(isset($tmp["UMvpasResultCode"])?$tmp["UMvpasResultCode"]:"");
		$this->convertedamount=(isset($tmp["UMconvertedAmount"])?$tmp["UMconvertedAmount"]:"");
		$this->convertedamountcurrency=(isset($tmp["UMconvertedAmountCurrency"])?$tmp["UMconvertedAmountCurrency"]:"");
		$this->conversionrate=(isset($tmp["UMconversionRate"])?$tmp["UMconversionRate"]:"");
		$this->error=(isset($tmp["UMerror"])?$tmp["UMerror"]:"");
		$this->errorcode=(isset($tmp["UMerrorcode"])?$tmp["UMerrorcode"]:"10132");
		$this->custnum=(isset($tmp["UMcustnum"])?$tmp["UMcustnum"]:"");
		$this->authamount=(isset($tmp["UMauthAmount"])?$tmp["UMauthAmount"]:"");
		$this->balance=(isset($tmp["UMremainingBalance"])?$tmp["UMremainingBalance"]:"");
		$this->cardlevelresult=(isset($tmp["UMcardLevelResult"])?$tmp["UMcardLevelResult"]:"");
		$this->procrefnum=(isset($tmp["UMprocRefNum"])?$tmp["UMprocRefNum"]:"");
		$this->profiler_score=(isset($tmp["UMprofilerScore"])?$tmp["UMprofilerScore"]:"");
		$this->profiler_response=(isset($tmp["UMprofilerResponse"])?$tmp["UMprofilerResponse"]:"");
		$this->profiler_reason=(isset($tmp["UMprofilerReason"])?$tmp["UMprofilerReason"]:"");
		$this->cardref=(isset($tmp["UMcardRef"])?$tmp["UMcardRef"]:"");
		
		// Obsolete variable (for backward compatibility) At some point they will no longer be set.
		//$this->avs=(isset($tmp["UMavsResult"])?$tmp["UMavsResult"]:"");
		//$this->cvv2=(isset($tmp["UMcvv2Result"])?$tmp["UMcvv2Result"]:"");
		
		
		if(isset($tmp["UMcctransid"])) $this->cctransid=$tmp["UMcctransid"];
		if(isset($tmp["UMacsurl"])) $this->acsurl=$tmp["UMacsurl"];
		if(isset($tmp["UMpayload"])) $this->pareq=$tmp["UMpayload"];
		
		if($this->resultcode == "A") return true;
		return false;
		
	}
	
	function ProcessQuickSale()
	{
		$this->command='quicksale';
		
		// check that we have the needed data
		$tmp=$this->CheckData();
		if($tmp)
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error=$tmp;
			$this->errorcode=10129;
			return false;
		}
		
				// Create hash if pin has been set.
		if(!trim($this->pin))
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error='Source key must have pin assigned to run transaction';
			$this->errorcode=999;
			return false;
		}
		
		// generate random seed value
		$seed = microtime(true) . rand();
		
		// assemble prehash data
		$prehash = $this->key . $seed . trim($this->pin);
		
		// hash the data
		$hash = sha1($prehash);
		
		
		$data = '<?xml version="1.0" encoding="UTF-8"?>' .
				'<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:ns1="urn:usaepay" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">' . 
				'<SOAP-ENV:Body>' .
				'<ns1:runQuickSale>' .
				'<Token xsi:type="ns1:ueSecurityToken">' .
				'<ClientIP xsi:type="xsd:string">' . $this->ip . '</ClientIP>' .
				'<PinHash xsi:type="ns1:ueHash">' .
				'<HashValue xsi:type="xsd:string">' . $hash . '</HashValue>' .
				'<Seed xsi:type="xsd:string">' . $seed . '</Seed>' . 
				'<Type xsi:type="xsd:string">sha1</Type>' .
				'</PinHash>' .
				'<SourceKey xsi:type="xsd:string">' . $this->key . '</SourceKey>' .
				'</Token>' .
				'<RefNum xsi:type="xsd:integer">' . preg_replace('/[^0-9]/','',$this->refnum) . '</RefNum>' .
				'<Details xsi:type="ns1:TransactionDetail">' . 
				'<Amount xsi:type="xsd:double">' . $this->xmlentities($this->amount) . '</Amount>' . 
				'<Description xsi:type="xsd:string">' . $this->xmlentities($this->description) . '</Description>'.
				'<Discount xsi:type="xsd:double">' . $this->xmlentities($this->discount) . '</Discount>' .
				'<Invoice xsi:type="xsd:string">' . $this->xmlentities($this->invoice) . '</Invoice>' .
				'<NonTax xsi:type="xsd:boolean">' . ($this->nontaxable?'true':'false') . '</NonTax>' .
				'<OrderID xsi:type="xsd:string">' . $this->xmlentities($this->orderid) . '</OrderID>' .
				'<PONum xsi:type="xsd:string">' . $this->xmlentities($this->ponum) . '</PONum>' .
				'<Shipping xsi:type="xsd:double">' . $this->xmlentities($this->shipping) . '</Shipping>' .
				'<Subtotal xsi:type="xsd:double">' . $this->xmlentities($this->subtotal) . '</Subtotal>' .
				'<Tax xsi:type="xsd:double">' . $this->xmlentities($this->tax) . '</Tax>' .
				'<Tip xsi:type="xsd:double">' . $this->xmlentities($this->tip) . '</Tip>' .
				'</Details>' .
				'<AuthOnly xsi:type="xsd:boolean">false</AuthOnly>' .
				'</ns1:runQuickSale>' .
				'</SOAP-ENV:Body>' .
				'</SOAP-ENV:Envelope>';
		
		// Figure out URL
		$url = ($this->gatewayurl?$this->gatewayurl:"https://www.usaepay.com/soap/gate/15E7FB61");
		if($this->usesandbox) $url = "https://sandbox.usaepay.com/soap/gate/15E7FB61";
		
		// Post data to Gateway
		$result=$this->httpPost($url, array('xml'=>$data));
		
		
		if($result===false) return false;
		
		if(preg_match('~<AuthCode[^>]*>(.*)</AuthCode>~', $result, $m)) $this->authcode=$m[1];
		if(preg_match('~<AvsResult[^>]*>(.*)</AvsResult>~', $result, $m)) $this->avs_result=$m[1];
		if(preg_match('~<AvsResultCode[^>]*>(.*)</AvsResultCode>~', $result, $m)) $this->avs_result_code=$m[1];
		if(preg_match('~<BatchRefNum[^>]*>(.*)</BatchRefNum>~', $result, $m)) $this->batch=$m[1];
		if(preg_match('~<CardCodeResult[^>]*>(.*)</CardCodeResult>~', $result, $m)) $this->cvv2_result=$m[1];
		if(preg_match('~<CardCodeResultCode[^>]*>(.*)</CardCodeResultCode>~', $result, $m)) $this->cvv2_result_code=$m[1];
		//if(preg_match('~<CardLevelResult[^>]*>(.*)</CardLevelResult>~', $result, $m)) $this->cardlevel_result=$m[1];
		//if(preg_match('~<CardLevelResultCode[^>]*>(.*)</CardLevelResultCode>~', $result, $m)) $this->cardlevel_result_code=$m[1];
		if(preg_match('~<ConversionRate[^>]*>(.*)</ConversionRate>~', $result, $m)) $this->conversionrate=$m[1];
		if(preg_match('~<ConvertedAmount[^>]*>(.*)</ConvertedAmount>~', $result, $m)) $this->convertedamount=$m[1];
		if(preg_match('~<ConvertedAmountCurrency[^>]*>(.*)</ConvertedAmountCurrency>~', $result, $m)) $this->convertedamountcurrency=$m[1];
		if(preg_match('~<Error[^>]*>(.*)</Error>~', $result, $m)) $this->error=$m[1];
		if(preg_match('~<ErrorCode[^>]*>(.*)</ErrorCode>~', $result, $m)) $this->errorcode=$m[1];
		//if(preg_match('~<isDuplicate[^>]*>(.*)</isDuplicate>~', $result, $m)) $this->isduplicate=$m[1];
		if(preg_match('~<RefNum[^>]*>(.*)</RefNum>~', $result, $m)) $this->refnum=$m[1];
		if(preg_match('~<Result[^>]*>(.*)</Result>~', $result, $m)) $this->result=$m[1];
		if(preg_match('~<ResultCode[^>]*>(.*)</ResultCode>~', $result, $m)) $this->resultcode=$m[1];
		if(preg_match('~<VpasResultCode[^>]*>(.*)</VpasResultCode>~', $result, $m)) $this->vpas_result_code=$m[1];
		
		
		// Store results
		if($this->resultcode == "A") return true;
		return false;
	}
	
	
	
	
	function ProcessQuickCredit()
	{
		$this->command='quickcredit';
		
		// check that we have the needed data
		$tmp=$this->CheckData();
		if($tmp)
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error=$tmp;
			$this->errorcode=10129;
			return false;
		}
		
				// Create hash if pin has been set.
		if(!trim($this->pin))
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error='Source key must have pin assigned to run transaction';
			$this->errorcode=999;
			return false;
		}
		
		// generate random seed value
		$seed = microtime(true) . rand();
		
		// assemble prehash data
		$prehash = $this->key . $seed . trim($this->pin);
		
		// hash the data
		$hash = sha1($prehash);
		
		$data = '<?xml version="1.0" encoding="UTF-8"?>' .
				'<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:ns1="urn:usaepay" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">' . 
				'<SOAP-ENV:Body>' .
				'<ns1:runQuickCredit>' .
				'<Token xsi:type="ns1:ueSecurityToken">' .
				'<ClientIP xsi:type="xsd:string">' . $this->ip . '</ClientIP>' .
				'<PinHash xsi:type="ns1:ueHash">' .
				'<HashValue xsi:type="xsd:string">' . $hash . '</HashValue>' .
				'<Seed xsi:type="xsd:string">' . $seed . '</Seed>' . 
				'<Type xsi:type="xsd:string">sha1</Type>' .
				'</PinHash>' .
				'<SourceKey xsi:type="xsd:string">' . $this->key . '</SourceKey>' .
				'</Token>' .
				'<RefNum xsi:type="xsd:integer">' . preg_replace('/[^0-9]/','',$this->refnum) . '</RefNum>' .
				'<Details xsi:type="ns1:TransactionDetail">' . 
				'<Amount xsi:type="xsd:double">' . $this->xmlentities($this->amount) . '</Amount>' . 
				'<Description xsi:type="xsd:string">' . $this->xmlentities($this->description) . '</Description>'.
				'<Discount xsi:type="xsd:double">' . $this->xmlentities($this->discount) . '</Discount>' .
				'<Invoice xsi:type="xsd:string">' . $this->xmlentities($this->invoice) . '</Invoice>' .
				'<NonTax xsi:type="xsd:boolean">' . ($this->nontaxable?'true':'false') . '</NonTax>' .
				'<OrderID xsi:type="xsd:string">' . $this->xmlentities($this->orderid) . '</OrderID>' .
				'<PONum xsi:type="xsd:string">' . $this->xmlentities($this->ponum) . '</PONum>' .
				'<Shipping xsi:type="xsd:double">' . $this->xmlentities($this->shipping) . '</Shipping>' .
				'<Subtotal xsi:type="xsd:double">' . $this->xmlentities($this->subtotal) . '</Subtotal>' .
				'<Tax xsi:type="xsd:double">' . $this->xmlentities($this->tax) . '</Tax>' .
				'<Tip xsi:type="xsd:double">' . $this->xmlentities($this->tip) . '</Tip>' .
				'</Details>' .
				'<AuthOnly xsi:type="xsd:boolean">false</AuthOnly>' .
				'</ns1:runQuickCredit>' .
				'</SOAP-ENV:Body>' .
				'</SOAP-ENV:Envelope>';
		
		// Figure out URL
		$url = ($this->gatewayurl?$this->gatewayurl:"https://www.usaepay.com/soap/gate/15E7FB61");
		if($this->usesandbox) $url = "https://sandbox.usaepay.com/soap/gate/15E7FB61";
		
		// Post data to Gateway
		$result=$this->httpPost($url, array('xml'=>$data));
		if($result===false) return false;
		
		if(preg_match('~<AuthCode[^>]*>(.*)</AuthCode>~', $result, $m)) $this->authcode=$m[1];
		if(preg_match('~<AvsResult[^>]*>(.*)</AvsResult>~', $result, $m)) $this->avs_result=$m[1];
		if(preg_match('~<AvsResultCode[^>]*>(.*)</AvsResultCode>~', $result, $m)) $this->avs_result_code=$m[1];
		if(preg_match('~<BatchRefNum[^>]*>(.*)</BatchRefNum>~', $result, $m)) $this->batch=$m[1];
		if(preg_match('~<CardCodeResult[^>]*>(.*)</CardCodeResult>~', $result, $m)) $this->cvv2_result=$m[1];
		if(preg_match('~<CardCodeResultCode[^>]*>(.*)</CardCodeResultCode>~', $result, $m)) $this->cvv2_result_code=$m[1];
		//if(preg_match('~<CardLevelResult[^>]*>(.*)</CardLevelResult>~', $result, $m)) $this->cardlevel_result=$m[1];
		//if(preg_match('~<CardLevelResultCode[^>]*>(.*)</CardLevelResultCode>~', $result, $m)) $this->cardlevel_result_code=$m[1];
		if(preg_match('~<ConversionRate[^>]*>(.*)</ConversionRate>~', $result, $m)) $this->conversionrate=$m[1];
		if(preg_match('~<ConvertedAmount[^>]*>(.*)</ConvertedAmount>~', $result, $m)) $this->convertedamount=$m[1];
		if(preg_match('~<ConvertedAmountCurrency[^>]*>(.*)</ConvertedAmountCurrency>~', $result, $m)) $this->convertedamountcurrency=$m[1];
		if(preg_match('~<Error[^>]*>(.*)</Error>~', $result, $m)) $this->error=$m[1];
		if(preg_match('~<ErrorCode[^>]*>(.*)</ErrorCode>~', $result, $m)) $this->errorcode=$m[1];
		//if(preg_match('~<isDuplicate[^>]*>(.*)</isDuplicate>~', $result, $m)) $this->isduplicate=$m[1];
		if(preg_match('~<RefNum[^>]*>(.*)</RefNum>~', $result, $m)) $this->refnum=$m[1];
		if(preg_match('~<Result[^>]*>(.*)</Result>~', $result, $m)) $this->result=$m[1];
		if(preg_match('~<ResultCode[^>]*>(.*)</ResultCode>~', $result, $m)) $this->resultcode=$m[1];
		if(preg_match('~<VpasResultCode[^>]*>(.*)</VpasResultCode>~', $result, $m)) $this->vpas_result_code=$m[1];
		
		
		// Store results		
		if($this->resultcode == "A") return true;
		return false;
	}
	
	function getSession()
	{
		$seed = md5(mt_rand());
		$action = 'getsession';
		
		// build hash
		$prehash = $action . ":" . $this->pin . ":" . $seed;
		$hash = 's/' . $seed . '/' . sha1($prehash);
		
		// Figure out URL
		$url = 'https://www.usaepay.com/interface/profiler/';
		if(preg_match('~https://([^/]*)/~i', $this->gatewayurl, $m)) {
			$url = 'https://' . $m[1] . '/interface/profiler/';
		}
		
		// Look for usesandbox
		if($this->usesandbox) $url = "https://sandbox.usaepay.com/interface/profiler/";
		
		// Add request paramters
		$url .=  $action . '?SourceKey=' . rawurlencode($this->key) . '&Hash=' . rawurlencode($hash);
		
		// Make Rest Call
		$output = file_get_contents($url);
		if(!$output) {
			$this->error = "Blank response";
			return false;
		}
		
		// Parse response
		$xml = simplexml_load_string($output);
		if(!$xml) {
			$this->error = "Unable to parse response";
			return false;
		}
		
		if($xml->Response!='A') {
			$this->error = $xml->Reason;
			$this->errorcode = $xml->ErrorCode;
			return false;
		}
		
		// assemble template
		$query ='org_id=' .$xml->OrgID . '&session_id=' . $xml->SessionID;
		$baseurl = "https://h.online-metrix.net/fp/";
		
		$out = '';
		$out .= '<p style="background:url('.$baseurl.'clear.png?'.$query.'&m=1)"></p>';
		$out .= '<img src="'.$baseurl.'clear.png?'.$query.'&m=2" width="1" height="1" alt="">';
		$out .= '<script src="'.$baseurl.'check.js?'.$query.'" type="text/javascript"></script>';
		$out .= '<object type="application/x-shockwave-flash" data="'.$baseurl.'fp.swf?'.$query.'" width="1" height="1" id="thm_fp">';
		$out .= '	<param name="movie" value="'.$baseurl.'fp.swf?'.$query.'" />';
		$out .= '<div></div></object>';
		
		return array('sessionid'=>$xml->SessionID, 'orgid'=>$xml->OrgID, 'html'=>$out);
	}
	
	/**
	 * Verify Proper Installation of USAePay class and required PHP Support
	 *
	 */
	function Test2()
	{
		$curl_version=false;
		?>
		<table border=1>
		<tr><th><b>Test</b></th><th><b>Result</b></th></tr>
		<tr><td valign="Top">Checking PHP Version</td>
		<td valign="top"><?php
			if(version_compare(phpversion(),"4.3.0")) {
				?><font color="green">Ok</font><br>
				PHP version <?php echo phpversion()?> on <?php echo PHP_OS?> detected. 
				<?php				
			} else {
				?><font color="red">Warning</font><br>
				PHP version <?php echo phpversion()?> detected. It is recommended that you
				upgrade to the most recent release of PHP.
				<?php				
			}
		?></td></tr>
		<tr><td valign="Top">Checking CURL Extension</td>
		<td valign="top"><?php
			if(function_exists("curl_version")) {	
				$tmp=curl_version();
				// PHP 5 returns an array,  version 4 returns a string
				if(is_array($tmp)) { 
					$curl_version=$tmp["version"];
					$curl_ssl_version=$tmp["ssl_version"];					
				} else {
					$tmp=explode(" ", $tmp);
					foreach($tmp as $piece)
					{
						list($lib,$version)=explode("/",$piece);
						if(stristr($lib,"curl")) $curl_version=$version;
						elseif(stristr($lib,"ssl")) $curl_ssl_version=$version;
					}
					
				}
				?><font color="green">Ok</font><br>
				Curl Extension (<?php echo $curl_version?>) detected.
				<?php
			} else {
				?><font color="red">Error</font><br>
				Your PHP installation does not include the Curl Extension. You must either enable the curl
				extension in your php.ini file by removing the semi-colon from the line ";extension=php_curl.dll" or recompile
				php with the configuration flag: "--with-curl"
				<?php
			}
		?>
		</td></tr>
		<tr><td valign="Top">Checking CURL SSL Support</td>
		<td valign="top"><?php
			if($curl_ssl_version) {	
				?><font color="green">Ok</font><br>
				SSL Version (<?php echo $curl_ssl_version?>) detected.
				<?php
			} else {
				?><font color="red">Error</font><br>
				It appears that your curl installation does not include support for the HTTPS (ssl) protocal
				Proper SSL installation is required to communicate with the USAePay gateway securely.  Please recompile curl
				with SSL support.
				<?php
			}
		?>					
		</td></tr>
		<tr><td valign="Top">Checking Communication with the Gateway</td>
		<td valign="top"><?php
			$ssl_failed=true;
			if(!$curl_version) {
				?><font color="red">Error</font><br>
				No curl support
				<?php				
			} else {
				$ch = curl_init(($this->gatewayurl?$this->gatewayurl:"https://www.usaepay.com/secure/gate.php") . "?VersionCheck=1&UMsoftware=" . rawurlencode($this->software));
				if(!$ch) {
					?><font color="red">Error</font><br>
					Curl failed to connect to server:  (NULL $ch returned)
					<?php
				} else {
					
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					if($this->cabundle) curl_setopt($ch, CURLOPT_CAINFO, $this->cabundle);				

					$result=curl_exec($ch);
					parse_str($result, $return);
					if($return["UMversion"]) {
						$ssl_failed=false;
						?><font color="green">Ok</font><br>
						Successfully connected to the gateway.  Detected version (<?php echo $return["UMversion"]?>) of the USAePay gateway API.
						<?php						
					} else {
						$ch = curl_init(($this->gatewayurl?$this->gatewayurl:"https://www.usaepay.com/secure/gate.php") . "?VersionCheck=1&UMsoftware=" . rawurlencode($this->software));
						if($this->cabundle) curl_setopt($ch, CURLOPT_CAINFO, $this->cabundle);				
						curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
						curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
						curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);				
						$result=curl_exec($ch);
						parse_str($result, $return);
						if($return["UMversion"]) {
							?><font color="red">Warning</font><br>
							
							Successfully connected to the gateway but could not verify SSL certificate.  This usually indicates that you
							do not have curl set up with the proper root CA certificate.  It is recommended that you install an up to date 
							root ca bundle.  As a <b>temporary</b> work around you may disable the ssl cert check by adding the following to your script:<br><br><tt>
							$tran->ignoresslcerterrors=true;<br>
							<br></tt>
							<?php						
							$ch = curl_init("https://www.verisign.com");
							if($this->cabundle) curl_setopt($ch, CURLOPT_CAINFO, $this->cabundle);				
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
							$result=curl_exec($ch);
							if(strlen($result)) {
								?>
								SSL certificate for VeriSign was validated sucessfully. This would indicate that you have a root CA bundle installed but that it
								is outdated. See below.
								<?php
							} else {
								?>
								Unable to verify SSL certificate for VeriSign.  This would indicate that you do not have a root CA bundle installed. See below.
								<?php
							}
												
							
							
						} else {
							$ch = curl_init("https://216.133.244.70/secure/gate.php?VersionCheck=1&UMsoftware=" . rawurlencode($this->software));
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
							curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
							curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
							$result=curl_exec($ch);
							parse_str($result, $return);
							if($return["UMversion"]) {
								?><font color="red">Warning</font><br>
								
								Successfully connected to the gateway using a static IP but could not connect using hostname. This would indicate
								that you do not have DNS setup correctly.  Please correct your server configuration to include a valid
								DNS server. As a temporary work around you may add the following to your script:<br><br><tt>
								$tran->ignoresslcerterrors=true;<br>
								$tran->gatewayurl="https://216.133.244.70/gate.php";<br>
								<br></tt>
								<?php
							} else {
								?><font color="red">Failed</font><br>
								Unable to establish connection to the USAePay Gateway.  It is possible that you are firewalling
								outbound traffic from your server.  To correct this problem,  you must add an allow entry in
								your firewall for ip <?php echo gethostbyname("www.usaepay.com")?> on port 443;
								<?php								
								
							}
							
						}
						
					}
				}				
			}
		?>					
		</td></tr>
		<?php if($ssl_failed) {?>
		
		<tr><td valign="Top">Looking for root CA Bundle</td>
		<td valign="top"><?php
			if(strstr(PHP_OS,"WIN")!==false) {
				foreach(array('c:\windows\ca-bundle.crt','c:\windows\curl-ca-bundle.crt') as $certpath)
				{
					if(is_file($certpath)) break;
					else unset($certpath);
				}
				
				if(!$certpath) $certpath="c:\windows\curl-ca-bundle.crt";
			} else {
				
				foreach(array("/usr/share/curl/curl-ca-bundle.crt","/usr/local/share/curl/curl-ca-bundle.crt","/etc/curl/curl-ca-bundle.crt") as $certpath)
				{
					if(is_file($certpath)) break;
					else unset($certpath);
				}
				
				if(!$certpath) $certpath="/usr/share/curl/curl-ca-bundle.crt";
			}
		
		
			if(is_readable($certpath)) {	
				?><font color="green">Ok</font><br>
				A root CA bundle was found in "<?php echo $certpath?>".  Since the above test failed,  its possible that curl is not
				correctly configured to use this bundle.  You can correct the problem by add the following code to your script:<br><br><tt>
				$tran->cabundle='<?php echo $certpath?>';
				</tt>
				<br><br>
				It is also possible that your root CA bundle is out dated. Your root CA bundle was last updated <?php echo date("m/d/y", filemtime($certpath))?>.
				You can download a new file from:
				<a href="https://www.usaepay.com/topics/curl-ca-bundle.crt">https://www.usaepay.com/topics/curl-ca-bundle.crt</a>				
				</tt>  
				<?php
			} else {
				?><font color="red">Error</font><br>
				Unable to locate your root CA bundle file. You can correct this by downloading a bundle file from: 

				<a href="https://www.usaepay.com/topics/curl-ca-bundle.crt">https://www.usaepay.com/topics/curl-ca-bundle.crt</a>
				Once downloaded save this file to: <?php echo $certpath?> You may also need to add the following code:<br><br><tt>
				$tran->cabundle='<?php echo $certpath?>';
				</tt> 
				<br><br>
				<?php
			}
		?>					
		</td></tr>
		<?php } ?>

		</table>
		<?php
	}
	
	function getFieldMap()
	{
		return array("UMkey" => 'key', 
			"UMcommand" => 'command',
			"UMauthCode" => 'origauthcode',
			"UMcard" => 'card',
			"UMexpir" => 'exp',
			"UMbillamount" => 'billamount', 
			"UMamount" => 'amount', 
			"UMinvoice" => 'invoice', 
			"UMorderid" => 'orderid', 
			"UMponum" => 'ponum', 
			"UMtax" => 'tax', 
			"UMnontaxable" => 'nontaxable',
			"UMtip" => 'tip', 
			"UMshipping" => 'shipping', 
			"UMdiscount" => 'discount', 
			"UMsubtotal" => 'subtotal', 
			"UMcurrency" => 'currency', 
			"UMname" => 'cardholder',
			"UMstreet" => 'street', 
			"UMzip" => 'zip',
			"UMdescription" => 'description',
			"UMcomments" => 'comments',
			"UMcvv2" => 'cvv2',
			"UMip" => 'ip',
			"UMtestmode" => 'testmode',
			"UMcustemail" => 'custemail',
			"UMcustreceipt" => 'custreceipt',
			"UMrouting" => 'routing',
			"UMaccount" => 'account',
			"UMssn" => 'ssn',
			"UMdlstate" => 'dlstate',
			"UMdlnum" => 'dlnum',
			"UMchecknum" => 'checknum',
			"UMaccounttype" => 'accounttype',
			"UMcheckformat" => 'checkformat',
			"UMcheckimagefront" => 'checkimage_front',
			"UMcheckimageback" => 'checkimage_back',
			"UMaddcustomer" => 'addcustomer',
			"UMrecurring" => 'recurring',
			"UMbillamount" => 'billamount',
			"UMbilltax" => 'billtax',
			"UMschedule" => 'schedule',
			"UMnumleft" => 'numleft',
			"UMstart" => 'start',
			"UMexpire" => 'end',
			"UMbillsourcekey" => 'billsourcekey',
			"UMbillfname" => 'billfname',
			"UMbilllname" => 'billlname',
			"UMbillcompany" => 'billcompany',
			"UMbillstreet" => 'billstreet',
			"UMbillstreet2" => 'billstreet2',
			"UMbillcity" => 'billcity',
			"UMbillstate" => 'billstate',
			"UMbillzip" => 'billzip',
			"UMbillcountry" => 'billcountry',
			"UMbillphone" => 'billphone',
			"UMemail" => 'email',
			"UMfax" => 'fax',
			"UMwebsite" => 'website',
			"UMshipfname" => 'shipfname',
			"UMshiplname" => 'shiplname',
			"UMshipcompany" => 'shipcompany',
			"UMshipstreet" => 'shipstreet',
			"UMshipstreet2" => 'shipstreet2',
			"UMshipcity" => 'shipcity',
			"UMshipstate" => 'shipstate',
			"UMshipzip" => 'shipzip',
			"UMshipcountry" => 'shipcountry',
			"UMshipphone" => 'shipphone', 
			"UMcardauth" => 'cardauth', 
			"UMpares" => 'pares', 
			"UMxid" => 'xid', 
			"UMcavv" => 'cavv', 
			"UMeci" => 'eci', 
			"UMcustid" => 'custid', 
			"UMcardpresent" => 'cardpresent', 
			"UMmagstripe" => 'magstripe', 
			"UMdukpt" => 'dukpt', 
			"UMtermtype" => 'termtype', 
			"UMmagsupport" => 'magsupport', 
			"UMcontactless" => 'contactless', 
			"UMsignature" => 'signature', 
			"UMsoftware" => 'software', 
			"UMignoreDuplicate" => 'ignoreduplicate', 
			"UMrefNum" => 'refnum',
			'UMauxonus' => 'auxonus',
			'UMepcCode' => 'epccode',
			'UMcustreceiptname' => 'custreceiptname',
			'UMallowPartialAuth' => 'allowpartialauth',
			'UMdigitalGoods' => 'digitalgoods',
			'UMmicr' => 'micr',
			'UMsession' => 'session',
			'UMisRecurring' => 'isrecurring',
			'UMclerk' => 'clerk',
			'UMtranterm' => 'terminal',
			'UMresttable' => 'restaurant_table',
			'UMticketedEvent' => 'ticketedevent',
			'UMifAuthExpired' => 'ifauthexpired',
			'UMauthExpireDays' => 'authexpiredays',
			'UMinventorylocation' => 'inventorylocation',
			'UMduty' => 'duty',
			'UMshipfromzip' => 'shipfromzip',
			'UMsaveCard' => 'savecard'
			
			);
	}
	function buildQuery($data)
	{
		if(function_exists('http_build_query') && ini_get('arg_separator.output')=='&') return http_build_query($data);
		
		$tmp=array();
		foreach($data as $key=>$val) $tmp[] = rawurlencode($key) . '=' . rawurlencode($val);
		

		return implode('&', $tmp);
		
	}
	
	function httpPost($url, $data)
	{				
		// if transport was not specified,  auto select transport
		if(!$this->transport)
		{
			if(function_exists("curl_version")) {
				$this->transport='curl';
			} else if(function_exists('stream_get_wrappers'))  {
				if(in_array('https',stream_get_wrappers())){
					$this->transport='stream';
				}
			}
		}
		
		
		// Use selected transport to post request to the gateway
		switch($this->transport)
		{
			case 'curl': return $this->httpPostCurl($url, $data);
			case 'stream': return $this->httpPostPHP($url, $data);
		}
						
		// No HTTPs libraries found,  return error		
		$this->result="Error";
		$this->resultcode="E";
		$this->error="Libary Error: SSL HTTPS support not found";
		$this->errorcode=10130;
		return false;					
	}
	
	function httpPostCurl($url, $data)
	{
		
		//init the connection
		$ch = curl_init($url);
		if(!is_resource($ch))
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error="Libary Error: Unable to initialize CURL ($ch)";
			$this->errorcode=10131;
			return false;			
		}
		
		// set some options for the connection
		curl_setopt($ch,CURLOPT_HEADER, 1);
		curl_setopt($ch,CURLOPT_POST,1);
		curl_setopt($ch,CURLOPT_TIMEOUT, ($this->timeout>0?$this->timeout:45));
		curl_setopt($ch,CURLOPT_RETURNTRANSFER,1);
		
		// Bypass ssl errors - A VERY BAD IDEA
		if($this->ignoresslcerterrors)
		{
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
			curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		}
		
		// apply custom ca bundle location
		if($this->cabundle)
		{	
			curl_setopt($ch, CURLOPT_CAINFO, $this->cabundle);				
		}
		
		// set proxy
		if($this->proxyurl)
		{
			curl_setopt ($ch, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
			curl_setopt ($ch, CURLOPT_PROXY, $this->proxyurl);
		}		
		
		$soapcall=false;
		if(is_array($data))
		{
			if(array_key_exists('xml',$data)) $soapcall=true;
		}
		
		if($soapcall)
		{
			curl_setopt($ch, CURLOPT_HTTPHEADER, array(
				"Content-type: text/xml;charset=UTF-8",
				"SoapAction: urn:ueSoapServerAction"
			));
			curl_setopt($ch,CURLOPT_POSTFIELDS,$data['xml']);
			
		} else {
			// rawurlencode data 
			$data = $this->buildQuery($data);		
			
			// attach the data
			curl_setopt($ch,CURLOPT_POSTFIELDS,$data);
		}
		
		// run the transfer
		$result=curl_exec ($ch);
		
		//get the result and parse it for the response line.
		if(!strlen($result))
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error="Error reading from card processing gateway.";
			$this->errorcode=10132;
			$this->blank=1;
			$this->transporterror=$this->curlerror=curl_error($ch);
			curl_close ($ch);
			return false;			
		}
		curl_close ($ch);
		$this->rawresult=$result;
		
		if($soapcall) {
			return $result;	
		}
		
		if(!$result) {
			$this->result="Error";
			$this->resultcode="E";
			$this->error="Blank response from card processing gateway.";
			$this->errorcode=10132;
			return false;			
		}
		
		// result will be on the last line of the return
		$tmp=explode("\n",$result);
		$result=$tmp[count($tmp)-1];		
		
		return $result;
	}
	
	function httpPostPHP($url, $data)
	{

		
		// rawurlencode data 
		$data = $this->buildQuery($data);		
		
		// set stream http options		
		$options = array(
			'http'=> array(
				'method'=>'POST',
	            'header'=> "Content-type: application/x-www-form-urlencoded\r\n"
	                . "Content-Length: " . strlen($data) . "\r\n",
	            'content' => $data,
	            'timeout' => ($this->timeout>0?$this->timeout:45),
	            'user_agent' => 'uePHPLibary v' . USAEPAY_VERSION . ($this->software?'/' . $this->software:'')
	        ),
	        'ssl' => array(
	            'verify_peer' => ($this->ignoresslcerterrors?false:true),
	            'allow_self_signed' => ($this->ignoresslcerterrors?true:false)	            
			)
		);
		
		if($this->cabundle) $options['ssl']['cafile'] = $this->cabundle;
		
		if(trim($this->proxyurl)) $options['http']['proxy'] = $this->proxyurl;
		
		
		// create stream context
		$context = stream_context_create($options);
		
		// post data to gateway
		$fd = fopen($url, 'r', null, $context);
		if(!$fd)
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error="Unable to open connection to gateway";
			$this->errorcode=10132;
			$this->blank=1;
			if(function_exists('error_get_last')) {
				$err=error_get_last();
				$this->transporterror=$err['message'];
			} else if(isset($GLOBALS['php_errormsg'])) {
				$this->transporterror=$GLOBALS['php_errormsg'];
			}
			//curl_close ($ch);
			return false;			
		}		
		
		// pull result
		$result = stream_get_contents($fd);

		// check for a blank response
		if(!strlen($result))
		{
			$this->result="Error";
			$this->resultcode="E";
			$this->error="Error reading from card processing gateway.";
			$this->errorcode=10132;
			$this->blank=1;
			fclose($fd);
			//$this->curlerror=curl_error($ch);
			//curl_close ($ch);
			return false;			
		}		
		
		fclose($fd);
		return $result;
		
	}
	
	function xmlentities($string)
	{
		$string = preg_replace('/[^a-zA-Z0-9 _\-\.\'\r\n]/e', '_uePhpLibPrivateXMLEntities("$0")', $string);
		return $string;
	}
	



######################### usaepay end ######################################################


	var $name = "Orders";
	var $uses = array (
		"User",
		"OrdersPayAsYouGoUser",
		"SubscriptionPlan",
		"ReguserOrder",
		"Order",
		"OrdersSubscribedPlansUser",
		"Configuration",
		"GenerateInvoice",
		"Discountcoupon",
		"Reference",
		"UserLocation",
		"WeighProduct",
		"OrderItem",
                "ShippingCharge"

	);
	var $helpers = array (
		'Html',
		'Form',
		'Javascript',
		'Ajax',
		'Time'
	);
	var $paginate = array (
		'limit' => '50',
		'page' => '1',
		'order' => array (
			'Order.id' => 'desc'
		)
	);
	var $components = array (
		'RequestHandler',
		"Logincheck",
		"Common"
	);


	function beforeFilter() {
		$loggedAdminId = $this->Session->read("adminid");
		if (isset ($this->params['admin']) && $this->params['admin'] && !$loggedAdminId) {
			$this->redirect("/admin/admins/login");
		}
	}

	/*admin function starts here
	* by deepshikha
	*
	*/
	function admin_index($id = null,$created = null, $toDate = null) {

		$this->layout = "admin";
		//	$this->set("expand_menu_links","testimonial");
		$condition = array ();
		$separator = array ();
		$urlSeparator = array ();

		$urlSeparator = implode("/", $urlSeparator);

		$this->set('separator', $separator);
		$this->set('urlSeparator', $urlSeparator);

		if (!empty ($this->data)) {

			if (isset ($this->data['Order']['search_order']) && $this->data['Order']['search_order'] != '') {
				$orderName = trim($this->data['Order']['search_order']);
			}

			if (isset ($this->data['Order']['action'])) {

				$idList = $this->data['Order']['idList'];
				if ($idList) {
					if ($this->data['Order']['action'] == "activate") {
						$cnd = array (
							"Order.id IN ($idList) "
						);
						$this->Order->updateAll(array (
							'Order.status' => "'1'"
						), $cnd);
					}
					elseif ($this->data['Order']['action'] == "deactivate") {
						$cnd = array (
							"Order.id IN ($idList) "
						);
						$this->Order->updateAll(array (
							'Order.status' => "'0'"
						), $cnd);
					}
					elseif ($this->data['Order']['action'] == "delete") {
						$cnd = array (
							"Order.id IN ($idList) "
						);
						$this->Order->deleteAll($cnd);
					}
				}
			}
		}
		elseif (!empty ($this->params)) {
			if (isset ($this->params['named']['search_order']) && $this->params['named']['search_order'] != '') {
				$orderName = trim($this->params['named']['search_order']);
			}
		}

		if (isset ($orderName) && $orderName != '') {
			$separator[] = 'order_type:' . $orderName;
			$condition[] = " (Order.order_type like '%" . $orderName . "%') ";
		}

                $todate = date("Y-m-d");
                if (isset ($id) && $id != '') {
			$separator[] = 'delivery_date:' . $todate;
			$condition[] = " (Order.delivery_date like '%" . $todate . "%') ";
			
			$this->set('IsTodaysOrder', "Yes");
		}

                $this->paginate = array(
                        'Order' => array(
                            'conditions' => array(''),
                            'fields'=>array('Order.*'),
                            'contain' => array(''),
                            'limit' => 10,
                            'order' => array(
                                'Order.id' => 'desc'
                            ),
                            'recursive' => -1
                            
                    ));
                $claim = $this->paginate('Order',$condition);
                
		$this->set('orders', $claim);

		if ($this->RequestHandler->isAjax()) {
			$this->layout = '';
			$this->viewPath = 'elements' . DS . 'admin/orders/';
			$this->render('index');
		}
	} //end of function index()

	function admin_deleteorders($id = NULL) {
		if ($id > 0) {
			$this->Order->delete($id);
			$this->viewPath = 'elements' . DS . 'admin';
			$this->Session->write('message', 'Order details deleted successfully.');
			$this->render('blank_delete');
			$this->redirect('/admin/orders/index');
		}
	} //end of admin_deleteUser

	function admin_deactivateOrder($id = NULL) {
		if ($id > 0) {
			$cnd = array (
				"Order.id = $id"
			);
			$this->Order->updateAll(array (
				'Order.status' => "'0'"
			), $cnd);
			$this->set('action', '/admin/orders/activateOrder/' . $id);
			$this->set('id', $id);
			$this->set('status', 0);
			$this->viewPath = 'elements' . DS . 'admin';
			$this->Session->write('message', 'Order details Deactivated successfully.');
			$this->render('update_status');
			$this->redirect('/admin/orders/index');
		}

	}

	function admin_activateOrder($id = NULL) {
		if ($id > 0) {
			$cnd = array ("Order.id = $id");
			$this->Order->updateAll(array ('Order.status' => "'1'"), $cnd);
			$this->set('action', '/admin/orders/deactivateOrder/' . $id);
			$this->set('id', $id);
			$this->set('status', 1);
			$this->viewPath = 'elements' . DS . 'admin';
			$this->Session->write('message', 'Order details Activated successfully.');
			$this->render('update_status');
			$this->redirect('/admin/orders/index');
		}
	} //end of admin_activateCustomer

	function admin_editOrders($id = NULL) { //echo '<pre>';print_r($this->data);exit;

		$this->layout = "admin";
		$msgString = '';
		$conditions = array ();
		$this->Order->id = $id;
		$orderDetails = $this->Order->read();		
		$this->set('oldweight', $orderDetails['OrdersSubscribedPlansUser']['total_weight']);

                $configDetails = $this->Configuration->find("first", array (
			"conditions" => "Configuration.id='1'",
			null
		));


                $userInfo = $this->User->find("first", array (
			"conditions" => "User.id='".$orderDetails['Order']['user_id']."'",
			null
		));


		global $minimum_usage;
		
		//global $overage_amount;
              
               $overage_amount = $configDetails['Configuration']['overage_amount'];
		//echo '<pre>'; print_r($this->data);exit;		
                    
		if ($this->data) {
                    
                    //echo "<pre>";print_r($this->data);
                    
                    $emailtemp_query=mysql_query("select * from emailtemplates where id='23' ");
                    $emailtemp_arr=mysql_fetch_array($emailtemp_query);
                    
                    $user_descrip_query=mysql_query("select first_name,email_address from users where id='".$this->data['Order']['user_id']."' ");
                    $user_descrip_arr=mysql_fetch_array($user_descrip_query);
                    
                    $updt_firsttime_stat='N';
                    
                    $updt_firsttime_qry=mysql_query("select already_update from orders where id='".$this->data['Order']['id']."'  ");
                    $updt_firsttime=mysql_fetch_array($updt_firsttime_qry);
                    
                    //print_r($updt_firsttime);
                    if(isset($updt_firsttime['already_update']))
                    {
                         $updt_firsttime_stat=$updt_firsttime['already_update'];
                    }
                    
                     $ordrstat_update=mysql_query('update orders set order_status="'.$this->data['Order']['order_status'].'"  WHERE id = "'.$this->data['Order']['id'].'"');
                       
                    
                    //exit;
                  //  print_r($user_descrip_arr);exit;
                    
                    $message_tosend='';
                    $subject_tosend='';

        if($updt_firsttime_stat=='N')            
        {            
                    /***********************/
                    /*
                        $today = date('Y-m-d');
                        $timestamp = strtotime($today);
                        $dayoftheweek = date('w',$timestamp);
                        if ($dayoftheweek == 0)
                        $dayoftheweek = 7;
                        
                        $monday= mktime(0, 0, 0, date("m",$timestamp) , date("d",$timestamp) - $dayoftheweek +0, date("Y",$timestamp));
                        $sunday= mktime(0, 0, 0, date("m",$timestamp) , date("d",$timestamp) + 6 - $dayoftheweek, date("Y",$timestamp));
                        $order_sunday=date('Y-m-d', $monday);
                        $order_satday=date('Y-m-d', $sunday);
                        
                        //$string="SELECT * FROM orders  WHERE  user_id='".$this->data['Order']['user_id']."'  AND (order_date BETWEEN '".$order_sunday."' AND '".$order_satday."')";
                        
                          $string="SELECT orders.*,reguser_orders.plan_id FROM orders,orders_subscribed_plans_users,reguser_orders
		                    WHERE  orders.user_id='".$this->data['Order']['user_id']."'
				    AND orders.id=orders_subscribed_plans_users.order_id
				    AND orders_subscribed_plans_users.plan_id=reguser_orders.id
				    AND  reguser_orders.plan_id='".$_POST['hid_plantypid']."'
				    AND orders.plan_typ_id='".$_POST['hid_plantypid']."'
		                    AND (orders.order_date BETWEEN '".$order_sunday."' AND '".$order_satday."')";
                                    
                    echo        $_POST['collg_extra_val'];  echo "<br>";     
                    echo        $_POST['collg_total_val'];                
                                    
                    exit;   
                    */
                    /*********************/
                    
                        //echo "<pre>";print_r($this->data);
                        $just_total_wght=$this->data['OrdersSubscribedPlansUser']['total_weight'];
                        
                        $firstedit_orderamount=$this->data['Order']['order_total']-$this->data['Order']['drycleaning_amount'];
                        $firstedit_ordertotal=$this->data['Order']['order_total'];
                        $firstedit_orderdry=$this->data['Order']['drycleaning_amount'];
                        
                        if($firstedit_orderamount==''){ $firstedit_orderamount=0; }
                        if($firstedit_ordertotal==''){ $firstedit_ordertotal=0; }
                        if($firstedit_orderdry==''){ $firstedit_orderdry=0; }
                        
                        
                        //echo $_POST['theplan_type'];
                
                        //print_r($week_array);
                        //echo 'Week from ' . date('d-m-Y', $monday) . ' to ' . date('d-m-Y', $sunday) ;
                         //$the_total_order_amt=($extra_pound*$overage_amount)+$the_dry_amt;
                        			
			$paymentstatusinfo = $this->ReguserOrder->find("first", array ("conditions" => array ("ReguserOrder.user_id = " . $this->data['Order']['user_id'],"ReguserOrder.payment_status = 'Confirm'","ReguserOrder.status = '1'"),'order' => 'ReguserOrder.id DESC',"limit" => "1"));
				

			if (isset ($this->data['Order']['order_amount']) && (!empty ($this->data['Order']['order_amount'])) && (!empty ($orderDetails['Order']['discount_coupon_code']))) {
				$this->data['Order']['discounted_order_amount'] = (($this->data['Order']['order_amount']) * ($configDetails['Configuration']['coupon_discount'])) / 100;
			}

                       
			if (isset ($this->data['OrdersPayAsYouGoUser']['total_weight']) && !empty ($this->data['OrdersPayAsYouGoUser']['total_weight'])) {
				$this->data['Order']['order_amount'] = ($this->data['OrdersPayAsYouGoUser']['total_weight']) * $overage_amount;
			}
			
                        
			/*
			 * Conditions for total weight & overages
			 * and calculates order amount
			 * by deepshikha
			 * on 14th june 2011
			 */
			 
			if (isset ($this->data['OrdersSubscribedPlansUser']['total_weight']) && !empty ($this->data['OrdersSubscribedPlansUser']['total_weight'])) {


				if (($this->data['OrdersSubscribedPlansUser']['total_weight'] >= $minimum_usage) && $this->data['OrdersSubscribedPlansUser']['total_weight'] > ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage'])) {
					//echo 'condition 1 if total>20 and total>remaining';

                                        
				    //	$this->data['Order']['order_amount'] = ($this->data['OrdersSubscribedPlansUser']['total_weight'] - ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage'])) * $overage_amount;
					
				} else
                                    
					if ($this->data['OrdersSubscribedPlansUser']['total_weight'] > ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage']) && $this->data['OrdersSubscribedPlansUser']['total_weight'] <= $minimum_usage) {
						//echo 'condition 2 if total>remaining and total<=15';
						$this->data['Order']['order_amount'] = ($minimum_usage - ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage'])) * $overage_amount;
					} else
						if ($this->data['OrdersSubscribedPlansUser']['total_weight'] == ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage']) && $this->data['OrdersSubscribedPlansUser']['total_weight'] < $minimum_usage) {
							//echo 'condition 3 total == remaining and total<15';//exit;
							$this->data['Order']['order_amount'] = ($minimum_usage - ($this->data['OrdersSubscribedPlansUser']['total_weight'])) * $overage_amount;                                                        
						} else
							if ($this->data['OrdersSubscribedPlansUser']['total_weight'] < ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage']) && $this->data['OrdersSubscribedPlansUser']['total_weight'] < $minimum_usage && ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage']) < $minimum_usage) {
								//echo 'condition 4 total < remaining and total<15';//exit;
								$this->data['Order']['order_amount'] = ($minimum_usage - ($paymentstatusinfo['ReguserOrder']['total_usage'] - $paymentstatusinfo['ReguserOrder']['used_usage'])) * $overage_amount;
							}

			}
                        //echo '<pre>'; print_r($this->data);exit;
						//exit;
						
			$this->data['Order']['order_total'] = $this->data['Order']['order_amount'] + $this->data['Order']['drycleaning_amount'];	 // added by mukund		
						
					//echo "<pre>";	
					//echo $this->data['OrdersPayAsYouGoUser']['total_weight'];
					//echo "<br>";
					//print_r($this->data);	   			
					//print_r($paymentstatusinfo);
					//print_r($orderDetails);
					//exit;
                                          
			$this->Order->save($this->data);                
                        
                        $Order_idval=$_POST['Order_idval'];
                        if($Order_idval=='') { $Order_idval=$id; }
                        
                        $abc='update orders set order_amount="'.$firstedit_orderamount.'", already_update="Y" ,
                                                                           order_total="'.$firstedit_ordertotal.'" ,
                                                                           drycleaning_amount="'.$firstedit_orderdry.'"
                                                                           
                                                                           WHERE id = "'.$Order_idval.'"
                                                        ';
                       $update_ordertable_one= mysql_query($abc);
                      
                        ////////////////////                
                                        
                                        
               if($_POST['theplan_type']!='N')
                  {
                    
                        $today = date('Y-m-d');
                        $timestamp = strtotime($today);
                        $dayoftheweek = date('w',$timestamp);
                        if ($dayoftheweek == 0)
                        $dayoftheweek = 7;
                        
                        $monday= mktime(0, 0, 0, date("m",$timestamp) , date("d",$timestamp) - $dayoftheweek +0, date("Y",$timestamp));
                        $sunday= mktime(0, 0, 0, date("m",$timestamp) , date("d",$timestamp) + 6 - $dayoftheweek, date("Y",$timestamp));
                        $order_sunday=date('Y-m-d', $monday);
                        $order_satday=date('Y-m-d', $sunday);
                        
                        //$string="SELECT * FROM orders  WHERE  user_id='".$this->data['Order']['user_id']."'  AND (order_date BETWEEN '".$order_sunday."' AND '".$order_satday."')";
                        
                        $string="SELECT orders.*,reguser_orders.plan_id FROM orders,orders_subscribed_plans_users,reguser_orders
		                    WHERE  orders.user_id='".$this->data['Order']['user_id']."'
				    AND orders.id=orders_subscribed_plans_users.order_id
				    AND orders_subscribed_plans_users.plan_id=reguser_orders.id
				    AND  reguser_orders.plan_id='".$_POST['hid_plantypid']."'
				    AND orders.plan_typ_id='".$_POST['hid_plantypid']."'
		                    AND (orders.order_date BETWEEN '".$order_sunday."' AND '".$order_satday."')";
                        
                        
                        
                        $the_order_id=$this->data['Order']['id'];
                        if($the_order_id=='') { $the_order_id=$id; }
                        
                        $the_plan_type=$_POST['theplan_type'];
                        $the_order_pound=$this->data['OrdersSubscribedPlansUser']['total_weight'];
                        $the_dry_amt=$this->data['Order']['drycleaning_amount'];
                       
                       $totalpound_week_before=0;
                       
                        $week_query_before= mysql_query($string);
                        while($week_array_before = mysql_fetch_assoc($week_query_before))
                        {
                          //  echo "<pre>";print_r($week_array);
                            $totalpound_week_before=$week_array_before['order_amount']+$totalpound_week_before;
                        } 
                         
                        
                        $update_ordertable= mysql_query('update orders set order_amount="'.$the_order_pound.'",
                                                                           drycleaning_amount="'.$the_dry_amt.'"
                                                                           WHERE id = "'.$the_order_id.'"
                                                        ');
                        
                        $week_query= mysql_query($string);
                        //$week_array = mysql_fetch_assoc($week_query);
                        
                        $extra_pound=0;
                        $totalpound_week=0;
                        $usage_per_week=$_POST['taketotal'];
                        
                        while($week_array = mysql_fetch_assoc($week_query))
                        {
                            $totalpound_week=$week_array['order_amount']+$totalpound_week;
                        }
                        
                       // echo $totalpound_week;echo "<br>";
                       $other_extra=0;
                         if($totalpound_week > $usage_per_week)
                         {
                            $string1=mysql_query("SELECT * FROM orders  WHERE  id!='".$the_order_id."'  AND user_id='".$this->data['Order']['user_id']."'  AND (order_date BETWEEN '".$order_sunday."' AND '".$order_satday."')");
                            while($week_array1 = mysql_fetch_assoc($string1))
                                {
                                    $other_extra=$week_array1['extra_amount']+$other_extra;
                                }
                            
                            $extra_pound=($totalpound_week-$usage_per_week)-$other_extra;
                           // echo $tp.'+'.$extra_pound;echo "<br>";
                            
                            $the_total_order_amt=($extra_pound*$overage_amount)+$the_dry_amt;
                           // echo $extra_pound.'+'.$the_total_order_amt;exit;
                            
                             $update_ordertable_2= mysql_query('update orders set order_total="'.$the_total_order_amt.'",
                                                                           extra_amount="'.$extra_pound.'"
                                                                           WHERE id = "'.$the_order_id.'"
                                                        ');
                            
                         }else{
                            $the_total_order_amt=$the_dry_amt;
                            $update_ordertable_2= mysql_query('update orders set order_total="'.$the_total_order_amt.'",
                                                                           extra_amount="0"
                                                                           WHERE id = "'.$the_order_id.'"
                                                        ');
                         }
                         //echo "hello";exit;
                         $collg_extra_val=0;$collg_total_val=0;
                         
                         if($_POST['collg_extra_val']!='')
                         {
                                $collg_extra_val= $_POST['collg_extra_val'];   
                         }
                         if($_POST['collg_total_val']!='')
                         {
                                $collg_total_val= $_POST['collg_total_val'];                   
                         }
                         
                          $update_ordertable_3= mysql_query('update orders set order_total="'.$collg_total_val.'",
                                                                           extra_amount="'.$collg_extra_val.'"
                                                                           WHERE id = "'.$the_order_id.'"
                                                        '); 
                         
                }
                                        
                                        
                        /////////////////////                
                      

			if ($this->data['Order']['order_type'] == 'Pay As You Go') {
			
				$this->OrdersPayAsYouGoUser->query("UPDATE orders_pay_as_you_go_users SET payment_status = '" . $this->data['OrdersPayAsYouGoUser']['payment_status'] . "', total_weight = '" . $this->data['OrdersPayAsYouGoUser']['total_weight'] . "' WHERE order_id = '" . $id . "'");
			} else {
                                
				////if ($this->data['OrdersSubscribedPlansUser']['total_weight'] < $minimum_usage && $this->data['OrdersSubscribedPlansUser']['total_weight'] != '0') { //echo 'total weight is right';exit;
				////	$this->data['OrdersSubscribedPlansUser']['total_weight'] = $minimum_usage;
				////}
                                 $ReguserOrder_id= $_POST['ReguserOrder_id'];
                                $string_select = "select * from reguser_orders where user_id='" . $ReguserOrder_id . "' AND status='1'";
                                $wght_select= mysql_query($string_select);$demo_wght=0;
                                while($wght_arrs = mysql_fetch_assoc($wght_select))
                                {
                                     $demo_wght=$wght_arrs['used_usage'];
                                }
                              //  echo "<pre>";print_r($wght_arrs);exit;
                                
                                if($this->data['OrdersSubscribedPlansUser']['total_weight']==null){ $notnull_wieght=0; }else{ $notnull_wieght=$this->data['OrdersSubscribedPlansUser']['total_weight']; }
                                $updated_weight = $notnull_wieght - $this->data['Order']['old_weight'];
                            
                                //$sum_take=$just_total_wght+$updated_weight+$demo_wght;
                                $sum_take=$just_total_wght+$demo_wght;
                            
                            //exit;    
				$this->OrdersSubscribedPlansUser->query("UPDATE orders_subscribed_plans_users SET total_weight = '" . $this->data['OrdersSubscribedPlansUser']['total_weight'] . "' WHERE order_id = '" . $id . "'");

                               
                                //actually this is the user id 
				$querypaymentinfo = "UPDATE reguser_orders SET used_usage = '" .$sum_take. "', payment_status = '" . $this->data['ReguserOrder']['payment_status'] . "' where user_id='" . $ReguserOrder_id . "' AND status='1'";
				
                                $resultpaymentinfo = mysql_query($querypaymentinfo) or die(mysql_error());

			}

   /*condition by deepshikha on 20110811
    * for sending notification
    * either via sms or email
    */
                            if($userInfo["User"]["notify_by"] == 'Sms'){

                                $ph = explode('-', $userInfo['User']['phone']);
                                $phone = $ph[0].$ph[1].$ph[2];

                                $this->Order->sendOrderStatusSms($phone,$id,$userInfo["User"]["first_name"]);
                            }
                            else if($userInfo["User"]["notify_by"] == 'Email'){
                                $this->Order->sendOrderStatusEmail($orderDetails["Order"]["user_id"], $id);
                            }
            }
                            /****************Mail sending code****************/
                            
                                if($this->data['Order']['order_status']=='Out for Delivery' || $this->data['Order']['order_status']=='Picked Up & Processing')
                                {         
                                     
                                     $arra3 = array('[!FIRSTNAME!]','[!ORDER_NO!]','[!ORDER_STATUS!]','[!SITE_TITLE!]','[!DATE!]','[!HTTP_PATH!]');
                                     $arra4 = array($user_descrip_arr['first_name'],'BTMO0'.$this->data['Order']['id'],$this->data['Order']['order_status'],SITE_TITLE,date('Y'),HTTP_PATH);
                                     
                                     $message_tosend=str_replace($arra3,$arra4,$emailtemp_arr['message']);
                                     
                                     if(isset($emailtemp_arr['subject']))
                                     {
                                         $subject_tosend=$emailtemp_arr['subject'];
                                     }
                                     
                                     //print_r($emailtemp_arr);
                                     
                                     $to_mail=$user_descrip_arr['email_address'];
                                     //$from='prasun@esolzmail.com';
                                     //$subject='This is BTM test';
                                     //$message='Hello debojit';
                                     //
                                     $headers = "MIME-Version: 1.0" . "\r\n";
                                     $headers .= "Content-type:text/html;charset=iso-8859-1" . "\r\n";
                                     
                                     //$headers.='From: BTM'.'<'.$from.'>';
                                     $headers .= "From: ".SITE_TITLE." <info@".SITE_TITLE_MAIL.".com>\r\n";
                                     //$headers .= 'From: '.$from."\r\n";
                                     
                                     mail($to_mail,$subject_tosend,$message_tosend,$headers);
                                 }
                            
                            /*****************End mail code***************/
                            
			$this->Session->write('message', 'Order details updated successfully.');
			//$this->redirect('/admin/orders/index');
                        $this->redirect('/admin/orders/editOrders/'.$id);

		} //end if($this->data){

		else {		
			$this->Order->id = $id;
			$this->data = $this->Order->read();
			
		} //end else
	} //end function admin_editOrders($id=NULL)

	function admin_viewOrder($id = NULL) {
		$this->layout = "admin";
		$this->Order->id = $id;
		$orderDetails = $this->Order->read();
                $this->set("orderDetails", $orderDetails);

                $shippingInfo = $this->ShippingCharge->find("first", array ("conditions" => array ("ShippingCharge.order_id = " . $id)));
                $this->set("shippingInfo", $shippingInfo);

                $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $id)));
                $this->set("ordereditemInfo", $ordereditemInfo);

	} //end function admin_viewOrder()


        function admin_viewTodayorder($id = NULL) {
		$this->layout = "admin";
		$this->Order->id = $id;
		$orderDetails = $this->Order->read();
                $this->set("orderDetails", $orderDetails);

                $shippingInfo = $this->ShippingCharge->find("first", array ("conditions" => array ("ShippingCharge.order_id = " . $id)));
                $this->set("shippingInfo", $shippingInfo);

                $userInfo = $this->User->find("all", array ("conditions" => array ("User.id = " . $orderDetails['Order']['user_id'])));
                $this->set("userInfo", $userInfo);

                $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $id)));
                $this->set("ordereditemInfo", $ordereditemInfo);

	} //end function admin_viewOrder()

       function admin_notifyUrl()
       {
          
         // $this->layout = "admin";
          //echo "hello";
//          $query_renewafter_month = "INSERT INTO zips (zip)
//                            VALUES ('1')";
//	  $result_renewafter_month = mysql_query($query_renewafter_month) or die(mysql_error());
//          
//          exit;
       }


         function admin_viewTodayorderPrint($id = NULL) {
		$this->layout = "";
		$this->Order->id = $id;
		$orderDetails = $this->Order->read();
                $this->set("orderDetails", $orderDetails);

                $shippingInfo = $this->ShippingCharge->find("first", array ("conditions" => array ("ShippingCharge.order_id = " . $id)));
                $this->set("shippingInfo", $shippingInfo);

                $userInfo = $this->User->find("all", array ("conditions" => array ("User.id = " . $orderDetails['Order']['user_id'])));
                $this->set("userInfo", $userInfo);

                $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $id)));
                $this->set("ordereditemInfo", $ordereditemInfo);

	} //end function admin_viewOrder()


	function admin_viewOrderPrint($id = NULL) {
		$this->layout = "";
		$this->Order->id = $id;
		$orderDetails = $this->Order->read();
		$this->set("orderDetails", $orderDetails);

                $shippingInfo = $this->ShippingCharge->find("first", array ("conditions" => array ("ShippingCharge.order_id = " . $id)));
                $this->set("shippingInfo", $shippingInfo);

                $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $id)));
                $this->set("ordereditemInfo", $ordereditemInfo);
	} //end function admin_viewOrder()

	function admin_generateInvoice($id = NULL) {

		$this->layout = "admin";
		$this->Order->id = $id;
		$orderDetails = $this->Order->read();


		$invoiceinfo = $this->GenerateInvoice->find("count", array (
			"conditions" => array (
				"GenerateInvoice.order_id = '" . $id . "'"
			),
			null
		));

                $shippingInfo = $this->ShippingCharge->find("first", array ("conditions" => array ("ShippingCharge.order_id = " . $id)));
                $this->set("shippingInfo", $shippingInfo);

                if($shippingInfo!=''){
                        $this->data['GenerateInvoice']['shipping_charge'] = $shippingInfo['ShippingCharge']['shipping_charge'];
                }

		if ($invoiceinfo > 0) {
			$this->Session->write('message', 'Invoice of this order is already generated.');
			$this->redirect('/admin/generate_invoices/index');
		} else {

			$this->data['GenerateInvoice']['user_id'] = $orderDetails['Order']['user_id'];
			$this->data['GenerateInvoice']['order_id'] = $orderDetails['Order']['id'];
			$this->data['GenerateInvoice']['plan_id'] = $orderDetails['ReguserOrder']['id'];
			$this->data['GenerateInvoice']['purchased_plan_id'] = $orderDetails['ReguserOrder']['plan_id'];
			$this->data['GenerateInvoice']['plan_purchased_date'] = $orderDetails['ReguserOrder']['plan_start_date'];
			$this->data['GenerateInvoice']['plan_expired_date'] = $orderDetails['ReguserOrder']['plan_expire_date'];
			$this->data['GenerateInvoice']['max_weight'] = (float) $orderDetails["ReguserOrder"]['total_usage'];
			$this->data['GenerateInvoice']['total_weight'] = (float) $orderDetails["OrdersSubscribedPlansUser"]['total_weight'];

			if ($orderDetails['Order']['order_amount'] != '') {
				$this->data['GenerateInvoice']['overage_amount'] = $orderDetails['Order']['order_amount'];
			} else {
				$this->data['GenerateInvoice']['overage_amount'] = '0';
			}


			$this->GenerateInvoice->save($this->data);

			$this->Session->write('message', 'Invoice of this order is generated successfully.');
			$this->redirect('/admin/generate_invoices/index');
		}
	} //end function admin_generateInvoice()

	/*
	 *CLIENT FUNCTION STARTS HERE BY Deepshikha Jain
	 */
	
        function admin_exportOrder($id=NULL){

                $this->layout="default";

		// to export to csv
                $contents   =   "";
		if($id == "csv")
		{		

                 //$contents = "User id,First Name,Last Name,Gender,Email,City,State,Zip,Phone \n";
                 $contents = "Email \n";
                 $contactInfo = $this->Order->find("all",array("conditions"=>"Order.status=1"));
                        

			for($cntr = 0; $cntr < count($contactInfo); $cntr++)
			{
				        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['id'].'"').",";
                                        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['first_name'].'"').",";
                                        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['last_name'].'"').",";
                                        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['gender'].'"').",";
                                        $contents.=stripslashes('"'.$contactInfo[$cntr]['Order']['order_no'].'"').",";
                                        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['city'].'"').",";
                                        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['state'].'"').",";
                                        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['zip'].'"').",";
                                        //$contents.=stripslashes('"'.$contactInfo[$cntr]['User']['phone'].'"').",";
                                        $contents.="\n";
			} //end for($cnt = 0; $cntr < count($customerInfo); $cntr++)


$fnamedate = date("Ymd");			
header('Content-Type: application/excel');
header('Content-Disposition: attachment; filename="order_'.$fnamedate.'.csv"');


$fp = fopen('php://output', 'w');
$i = 0;
foreach ( $contactInfo as $line ) {   
	if($i==0){
		$TemoArray = array("Customer Name","Address","Phone Number","SPOT","Laundry/DC","Pick-up Location","Drop-off Location","Order For","Order Notes"); 
		fputcsv($fp,$TemoArray);
	}
	
	$queryuserinfo = "select first_name, last_name, address, phone, spot from users where id='".$line['Order']['user_id']."'";
    $resultuserinfo = mysql_query($queryuserinfo);
    $rowuserinfo = mysql_fetch_assoc($resultuserinfo);
		
	$TemoArray = array($rowuserinfo['first_name']." ".$rowuserinfo['last_name'],$rowuserinfo['address'],$rowuserinfo['phone'],$rowuserinfo['spot'],$line['Order']['order_plan_type'],$line['Order']['pickup_location'],$line['Order']['delivery_location'],$line['Order']['pickup_notes'],$line['Order']['order_notes']); 
	fputcsv($fp,$TemoArray);
   // fputcsv($fp, $line);
   $i++;
}
fclose($fp);
exit;
			/*$contents = strip_tags($contents); 
			$date = date("Ymd");			
			$fileName = "Newsletter_Subscribers_".$date.".csv";
			header("Content-Disposition: attachment; filename=$fileName");
			print $contents;
			exit;*/

		} //end if($id == "csv")

	} //end function
	 

	function pay_as_you_go($id = null) {
	
		global $overage_amount;
		global $cardno;

		$this->layout = "client";
		$this->set('active', "order");		
		$this->userLoginCheck();		
		$errorMessage = "";

                $user_detail = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			)
		));
		

                // added by devendra 20120405

                if(empty ($user_detail['User']['address']) || empty ($user_detail['User']['city']) || empty ($user_detail['User']['state']) || empty ($user_detail['User']['zip']))
                {
                    $this->Session->write('message',__('Your delivery information is not complete, Kindly fill your delivery info.',true));
                    $this->redirect('/users/account_step2');
                }

		$configDetails = $this->Configuration->find("first", array (
			"conditions" => "Configuration.id='1'",
			null
		));
                $this->set('configDetails',$configDetails);

		$userAddress = $this->User->find("list", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			),
			"fields" => array (
				"User.id",
				"User.address"
			)

		));



		$this->set("address", $userAddress);

		$userInfo = $this->User->find("first", array (
			"conditions" => "User.id = '" . $this->Session->read('user_id') . "'"
		));
		$this->set("userInfo", $userInfo);

		$locationInfo = $this->UserLocation->find("list", array (
			"conditions" => array (
				"UserLocation.user_id = '" . $this->Session->read('user_id') . "'"
			),
			"fields" => array ("UserLocation.address","UserLocation.address")));

		$this->set("locationInfo", $locationInfo);


		if ($this->data) {

			if (empty ($this->data['Order']['pickup_date'])) {
				$errorMessage .= "Please Enter Pickup Date.<br>";
			}
                        elseif(date('l',strtotime($this->data['Order']['pickup_date'])) == 'Sunday')
                        {
                                $errorMessage .= "We are closed on Sunday<br>
                                                  Please select another day for your pickup or delivery.<br>";
                        }

			if (empty ($this->data['Order']['delivery_date'])) {
				$errorMessage .= "Please Enter Delivery Date.<br>";
			}
                        elseif(date('l',strtotime($this->data['Order']['delivery_date'])) == 'Sunday')
                        {
                                $errorMessage .= "We are closed on Sunday<br>
                                                  Please select another day for your pickup or delivery.<br>";
                        }

			if (isset ($errorMessage) && $errorMessage != "") {
				$this->Session->write("message", $errorMessage);
			} else {


				/*code for giving discount with coupon code will be used when weight calculator part will be done
				 * order amount will be calculated
				 * when weight calculator will be implemented
				 * after order amount, discounted order amount will be calculated.
				 * so this is static for now.
				 */

				//by deepshikha on 29th june $this->data['Order']['order_amount'] = ($count_weight)*$overage_amount;

				//$this->data['Order']['order_amount'] = $configDetails['Configuration']['authorize_amount'];
                                 $this->data['Order']['order_amount'] = 0;
				if (!empty ($this->data['Order']['discount_coupon_code'])) {

					$couponInfo = $this->Discountcoupon->find("first", array (
						"conditions" => array (
							"Discountcoupon.coupon_code = '" . $this->data['Order']['discount_coupon_code'] . "'"
						),
						null
					));

                                        $userInfo = $this->User->find("first", array (
						"conditions" => array (
							"User.id = '" . $couponInfo['Discountcoupon']['from_id'] . "'"
						),
						null
					));


                                        //if coupon is for referral
					if ($couponInfo['Discountcoupon']['status'] == '1' && $couponInfo['Discountcoupon']['current_status'] == 'not used' && $couponInfo['Discountcoupon']['discount_percentage']!='0.00' && $couponInfo['Discountcoupon']['discount_amount']=='0.00') {

                                                if($couponInfo['Discountcoupon']['to_email'] == $this->Session->read('user_email') && $couponInfo['Discountcoupon']['coupon_usage'] == 'Single'){  //echo 'first if';exit;
                                                        $this->data['Order']['discounted_order_amount'] = (($this->data['Order']['order_amount']) * ($configDetails['Configuration']['coupon_discount'])) / 100;
                                                        $this->data['Order']['discount_percentage'] = $configDetails['Configuration']['coupon_discount'];
                                                        $this->Discountcoupon->query("UPDATE discountcoupons SET current_status = 'used', status = '0' WHERE coupon_code = '" . $this->data['Order']['discount_coupon_code'] . "'");
                                                        $this->Discountcoupon->sendCouponUsedEmail($userInfo["User"]["email_address"],$userInfo['User']['first_name'],$this->Session->read('user_email'));
                                                }
                                                else if($couponInfo['Discountcoupon']['to_email'] == $this->Session->read('user_email') && $couponInfo['Discountcoupon']['coupon_usage'] == 'Multiple'){ //echo 'first if else';exit;
                                                        $this->data['Order']['discounted_order_amount'] = (($this->data['Order']['order_amount']) * ($couponInfo['Discountcoupon']['discount_percentage'])) / 100;
                                                }
                                                else if($couponInfo['Discountcoupon']['to_email'] == NULL && $couponInfo['Discountcoupon']['coupon_usage'] == 'Single'){ //echo '2 if else';exit;
                                                        $this->data['Order']['discounted_order_amount'] = (($this->data['Order']['order_amount']) * ($couponInfo['Discountcoupon']['discount_percentage'])) / 100;
                                                        $this->Discountcoupon->query("UPDATE discountcoupons SET current_status = 'used', status = '0' WHERE coupon_code = '" . $this->data['Order']['discount_coupon_code'] . "'");
                                                }
                                                else if($couponInfo['Discountcoupon']['to_email'] == NULL && $couponInfo['Discountcoupon']['coupon_usage'] == 'Multiple'){ //echo '3 if else';exit;
                                                        $this->data['Order']['discounted_order_amount'] = (($this->data['Order']['order_amount']) * ($couponInfo['Discountcoupon']['discount_percentage'])) / 100;
                                                }
                                                else{ //echo 'else';exit;
                                                      $this->Session->write("message", 'You are not authorized to use this coupon.');
                                                      $this->redirect('/orders/pay_as_you_go/');
                                                }

					}

                                        //if coupon is created by administrator.

                                        elseif($couponInfo['Discountcoupon']['status'] == '1' && $couponInfo['Discountcoupon']['current_status'] == 'not used' && $couponInfo['Discountcoupon']['discount_percentage']=='0.00' && $couponInfo['Discountcoupon']['discount_amount']!='0.00') {

                                                if($couponInfo['Discountcoupon']['to_email'] == $this->Session->read('user_email') &&  $couponInfo['Discountcoupon']['coupon_usage'] == 'Single'){ //echo '1 if';exit;
                                                        if(($this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount']) > '0.00'){
                                                            $this->data['Order']['discounted_order_amount'] = $this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount'];
                                                        }else{
                                                            $this->data['Order']['discounted_order_amount'] = '0.00';
                                                        }

                                                        $this->Discountcoupon->query("UPDATE discountcoupons SET current_status = 'used', status = '0' WHERE coupon_code = '" . $this->data['Order']['discount_coupon_code'] . "'");
                                                }
                                                else if($couponInfo['Discountcoupon']['to_email'] == $this->Session->read('user_email') &&  $couponInfo['Discountcoupon']['coupon_usage'] == 'Multiple'){ //echo '1 if else';exit;
                                                        if(($this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount']) > '0.00'){
                                                            $this->data['Order']['discounted_order_amount'] = $this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount'];
                                                        }else{
                                                            $this->data['Order']['discounted_order_amount'] = '0.00';
                                                        }
                                                }
                                                else if($couponInfo['Discountcoupon']['to_email'] == NULL && $couponInfo['Discountcoupon']['coupon_usage'] == 'Multiple'){ //echo '2 if else';exit;
                                                        if(($this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount']) > '0.00'){
                                                            $this->data['Order']['discounted_order_amount'] = $this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount'];
                                                        }else{
                                                            $this->data['Order']['discounted_order_amount'] = '0.00';
                                                        }
                                                }
                                                else if($couponInfo['Discountcoupon']['to_email'] == NULL && $couponInfo['Discountcoupon']['coupon_usage'] == 'Single'){ //echo '3 if else';exit;
                                                        if(($this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount']) > '0.00'){
                                                            $this->data['Order']['discounted_order_amount'] = $this->data['Order']['order_amount'] - $couponInfo['Discountcoupon']['discount_amount'];
                                                        }else{
                                                            $this->data['Order']['discounted_order_amount'] = '0.00';
                                                        }
                                                        $this->Discountcoupon->query("UPDATE discountcoupons SET current_status = 'used', status = '0' WHERE coupon_code = '" . $this->data['Order']['discount_coupon_code'] . "'");
                                                }
                                                else{ //echo 'else';exit;
                                                      $this->Session->write("message", 'You are not authorized to use this coupon.');
                                                      $this->redirect('/orders/pay_as_you_go/');
                                                }

					}
                                        else {
						$this->data['Order']['discounted_order_amount'] = $this->data['Order']['order_amount'];
						$this->Session->write("message", 'Coupon is already used.');
						$this->redirect('/orders/pay_as_you_go/');
					}

				} else
					if (empty ($this->data['Order']['discount_coupon_code']) && !empty ($userInfo['User']['coupon_code'])) {
						$couponInfo = $this->Discountcoupon->find("first", array (
							"conditions" => array (
								"Discountcoupon.coupon_code = '" . $userInfo['User']['coupon_code'] . "'"
							),
							null
						));

						if ($couponInfo['Discountcoupon']['status'] == '0' && $couponInfo['Discountcoupon']['current_status'] == 'used' && $couponInfo['Discountcoupon']['discount_percentage']!='0.00') {
							$this->data['Order']['discounted_order_amount'] = (($this->data['Order']['order_amount']) * ($configDetails['Configuration']['coupon_discount'])) / 100;
                                                        $this->data['Order']['discount_percentage'] = $configDetails['Configuration']['coupon_discount'];
						} else {
							$this->data['Order']['discounted_order_amount'] = $this->data['Order']['order_amount'];
						}

					} else {
						$this->data['Order']['discounted_order_amount'] = $this->data['Order']['order_amount'];
					}

				$this->data['Order']['order_type'] = 'Pay As You Go';
                                $this->data['Order']['user_id'] = $this->Session->read('user_id');
				$this->data['Order']['delivery_date'] = date('Y-m-d', strtotime($this->data['Order']['delivery_date']));
				$this->data['Order']['pickup_date'] = date('Y-m-d', strtotime($this->data['Order']['pickup_date']));
				$this->data['Order']['order_date'] = date('Y-m-d H:i:s');
                                $this->data['Order']['order_status'] = 'Scheduled Pickup';
				$this->data['Order']['status'] = '1';
				$this->data['Order']['id'] = $id;
				//echo "<pre>";print_r($this->data);exit;
				
				$this->Order->save($this->data);


				$this->Reference->query("UPDATE references SET purchase_confirmation = '1', date_confirmed_purchase = '" . date('Y-m-d H:i:s') . "' WHERE coupon_code = '" . $this->data['Order']['discount_coupon_code'] . "'");

				$this->User->query("UPDATE users SET coupon_code = '' WHERE id = '" . $this->Session->read('user_id') . "'");

				$form_order_id = $cardno . str_pad($this->Order->id, 5, "0", STR_PAD_LEFT);
				$this->data['Order']['id'] = $this->Order->id;
				$this->data['Order']['order_no'] = $form_order_id;
				$orderNoArray = array ();
				$orderNoArray['Order']['id'] = $this->data['Order']['id'];
				$orderNoArray['Order']['order_no'] = $this->data['Order']['order_no'];				
				$this->Order->save($orderNoArray);

				$orderid = $this->Order->id;

                if (empty ($id) || $id == 0) {
					$this->data['OrdersPayAsYouGoUser']['order_id'] = $orderid;
					$this->data['OrdersPayAsYouGoUser']['payment_status'] = 'Pending';
						$this->data['OrdersPayAsYouGoUser']['amount_captured_status'] = 'not captured';
						//echo '<pre>';print_r($this->data);exit;
					$this->OrdersPayAsYouGoUser->save($this->data);
				}

				$this->Session->write("message", "Order Confirmation");
				$this->redirect('/orders/payment_preview_payasugo/' . $this->Order->id);
			}
		} else {
			if (isset ($id)) {
				$this->Order->id = $id;
				$this->data = $this->Order->read();
                                $this->set('id',$id);
                                $orderitemdetails = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $id),null));
                                $this->set('orderitemdetails',$orderitemdetails);
                                //echo '<pre>';print_r($orderitemdetails);exit;
			}
		}
	} //end function pay_As_you_Go()

	function order_schedule_subscribed_plan($id = null) {
		//echo $id;exit;
		$this->layout = "client";
		$this->set('active', "order");
		$this->userLoginCheck();
		$errorMessage = "";

                $user_detail = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			)
		));

                if($this->Session->read('user_id'))
                {
                     $query_update_deb = mysql_query("select * from reguser_orders   WHERE user_id = '".$this->Session->read('user_id')."'");
                     $issubscribed=mysql_num_rows($query_update_deb);
                     
                  //  echo "<pre>";print_r($issubscribed);exit;
                  //echo $issubscribed;exit;
                        if($issubscribed=='' || $issubscribed ==0 )
                        {
                            //redirect('/page/get_started');
                            $this->redirect('/page/get_started');
                        }
                }
                
                // added by devendra 20120405

                if(empty ($user_detail['User']['address']) || empty ($user_detail['User']['city']) || empty ($user_detail['User']['state']) || empty ($user_detail['User']['zip']))
                {
                    $this->Session->write('message',__('Your delivery information is not complete, Kindly fill your delivery info.',true));
                    $this->redirect('/users/account_step2');
                }

		$userAddress = $this->User->find("list", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			),
			"fields" => array (
				"User.id",
				"User.address"
			)
		));
		$this->set("address", $userAddress);

		$paymentstatusinfo = $this->ReguserOrder->find("first", array (
			"conditions" => array (
				"ReguserOrder.user_id = " . $this->Session->read('user_id'),
				"ReguserOrder.payment_status = 'Confirm'",
				"ReguserOrder.status = '1'"
			),
			'order' => 'ReguserOrder.id DESC',
			"limit" => "1"
		));
		$this->set('paymentstatusinfo', $paymentstatusinfo);

		$locationInfo = $this->UserLocation->find("list", array (
			"conditions" => array (
				"UserLocation.user_id = '" . $this->Session->read('user_id') . "'"
			),
			"fields" => array ("UserLocation.address","UserLocation.address")));

		$this->set("locationInfo", $locationInfo);

		if ($this->data) {

			if (empty ($this->data['Order']['pickup_date'])) {
				$errorMessage .= "Please Enter Pickup Date.<br>";
			}
                        elseif(date('l',strtotime($this->data['Order']['pickup_date'])) == 'Sunday')
                        {
                                $errorMessage .= "We are closed on Sunday<br>
                                                  Please select another day for your pickup or delivery.<br>";
                        }
                        
			if (empty ($this->data['Order']['delivery_date'])) {
				$errorMessage .= "Please Enter Delivery Date.<br>";
			}
                        elseif(date('l',strtotime($this->data['Order']['delivery_date'])) == 'Sunday')
                        {
                                $errorMessage .= "We are closed on Sunday<br>
                                                  Please select another day for your pickup or delivery.<br>";
                        }

			if (isset ($errorMessage) && $errorMessage != "") {
				$this->Session->write("message", $errorMessage);
			} else {

                             $get_plantyp = mysql_query("select * from reguser_orders   WHERE user_id = '".$this->Session->read('user_id')."' and payment_status='Confirm' and status='1' and 	is_activated='1' and  plan_expire_date!='".NULL."' and  plan_start_date!='".NULL."'  ");
                             $get_plantyp_arr=mysql_fetch_assoc($get_plantyp);
                             //echo "<pre>";print_r($get_plantyp_arr);exit;
                             $plan_typ_id=$get_plantyp_arr['plan_id'];
                        
				$this->data['Order']['user_id'] = $this->Session->read('user_id');
				$this->data['Order']['order_type'] = 'Subscription';
				$this->data['Order']['order_date'] = date('Y-m-d H:i:s');
				$this->data['Order']['delivery_date'] = date('Y-m-d', strtotime($this->data['Order']['delivery_date']));
				$this->data['Order']['pickup_date'] = date('Y-m-d', strtotime($this->data['Order']['pickup_date']));
                                $this->data['Order']['order_status'] = 'Scheduled Pickup';
				$this->data['Order']['status'] = '1';
                                $this->data['Order']['plan_typ_id'] = $plan_typ_id;

				$this->Session->write("order_sumry", $this->data);
				$this->Session->write("message", "Order Confirmation");
				$this->redirect('/orders/payment_preview/' . $this->Order->id);
			}
		} else {
			$this->Order->id = $id;
			$this->data = $_SESSION['order_sumry'];
		}
	}

	function payment_preview($order_id = null) {
		$this->layout = "client";
		$this->set('active', "");
		$this->userLoginCheck();
		$errorMessage = "";

		$userAddress = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			)
		));
		$this->set("userAddress", $userAddress);

		$userInfo = $this->Session->read('order_sumry');
		$this->set("userInfo", $userInfo);
	}

	function payment_preview_payasugo($order_id = null) {
		$this->layout = "client";
		$this->set('active', "");
		$this->userLoginCheck();
		$errorMessage = "";

		if (isset ($order_id)) {

			$this->Order->id = $order_id;

			$userInfo = $this->Order->read();
                        $this->set("userInfo", $userInfo);

                        $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $order_id)));
                        $this->set("ordereditemInfo", $ordereditemInfo);

		}
	}

	function payment($order_id = null) {

		$this->layout = "client";
		$this->set('active', "");
		$this->userLoginCheck();
		$errorMessage = "";

		$userAddress = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			)
		));

		$this->set("userAddress", $userAddress);


                $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $order_id)));
                $this->set("ordereditemInfo", $ordereditemInfo);

		$configDetails = $this->Configuration->find("first", array (
			"conditions" => "Configuration.id='1'",
			null
		));
		
		$tran=$this;
		if ($configDetails['Configuration']['payment_mode'] == "sandbox") {
			//$environment = "sandbox";
			$tran->usesandbox=true;    
		} else {
			//$environment = "";
			$tran->usesandbox=true;    
		}

		if (isset ($order_id)) {
			$userInfo = $this->Order->find("first", array (
				"conditions" => array (
					"Order.user_id = " . $this->Session->read('user_id'),
					"Order.id = " . $order_id
				)
			));
			$this->set("userInfo", $userInfo);

			if (isset ($configDetails['Configuration']['authorize_amount']) && $configDetails['Configuration']['authorize_amount'] != '0.00') {
			
				//$tran->key="JQ2ES5j5P9xXNTjR5vFpMI0DDT5vtaJ8";  // This is live key
				//$tran->pin="BTML";
				
				//$tran->key="SSn41U99mGh3siG73kQ1o16QsmjRIhSm";    // This is test key
				//$tran->pin="1234";
				
				$tran->key="_rXxx6Q6h1vW81bH9v55IKa6OrJMP7La";  // This is test key
				$tran->pin="1234";										
				
				$expMonth = $userAddress['User']['expiration_card_month'];
				$expYear = $userAddress['User']['expiration_card_year'];
				
				$tran->card=urlencode($userAddress['User']['card_number']);
				$tran->exp=urlencode(str_pad($expMonth, 2, '0', STR_PAD_LEFT)).$expYear;			
				$tran->amount=urlencode($configDetails['Configuration']['authorize_amount']);	
				$tran->invoice="1234";   		
				$tran->cardholder= urlencode($userAddress['User']['first_name'])." ".urlencode($userAddress['User']['last_name']);
				$tran->street=urlencode($userAddress['User']['billing_address']);	
				$tran->zip=urlencode($userAddress['User']['billing_zip']);			
				$tran->description="Online Order";	
				$tran->cvv2=urlencode($userAddress['User']['card_number_cvv']);								
				flush();
						
				
				        } //end if amount not equal to zero

                        /*by deepshikha*/

                        if($tran->Process()) {
						
							$authorizationID = $tran->cctransid;
						
                            $query_update = "UPDATE orders_pay_as_you_go_users SET payment_status='Confirm',status='1',transaction_id='" . $authorizationID . "' WHERE order_id = '" . $order_id . "'";
                            mysql_query($query_update) or die(mysql_error());


                            $this->Order->sendGenerateOrderEmailToAdmin($userAddress["User"]["email_address"], $order_id);

                          /*by deepshikha for sending sms if notification type is sms or email if notification type is email*/
                            if($userAddress["User"]["notify_by"] == 'Sms'){

                                $ph = explode('-', $userAddress['User']['phone']);
                                $phone = $ph[0].$ph[1].$ph[2];

                                $this->Order->sendSms($phone, $order_id, $userAddress["User"]["first_name"]);
                            }else if($userAddress["User"]["notify_by"] == 'Email'){
                                $this->Order->sendGenerateOrderEmail($userAddress["User"]["email_address"], $order_id);
                            }
                          /* end by deepshikha*/

                            //echo "<pre>";pr($httpParsedResponseArCapture);exit;

                            $this->Session->write("message", "Your order has been placed.  You just saved a few hours of work with a few clicks of a mouse!");
                        }else{

                            $query_delete = "DELETE from orders_pay_as_you_go_users WHERE order_id = '" . $order_id . "'";
                            mysql_query($query_delete) or die(mysql_error());

                            $this->Session->write("message", "This transaction cannot be processed. Please update your credit card information!");
                            $this->redirect('/orders/pay_as_you_go');
                        }
		}
	} //end function payment()


	function payment_backup($order_id = null) {
	
		$this->layout = "client";
		$this->set('active', "");
		$this->userLoginCheck();
		$errorMessage = "";
//exit;
		$userAddress = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			)
		));

		$this->set("userAddress", $userAddress);


                $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $order_id)));
                $this->set("ordereditemInfo", $ordereditemInfo);

		$configDetails = $this->Configuration->find("first", array (
			"conditions" => "Configuration.id='1'",
			null
		));

		if ($configDetails['Configuration']['payment_mode'] == "sandbox") {
			$environment = "sandbox";
		} else {
			$environment = "";
		}

		if (isset ($order_id)) {
			$userInfo = $this->Order->find("first", array (
				"conditions" => array (
					"Order.user_id = " . $this->Session->read('user_id'),
					"Order.id = " . $order_id
				)
			));
			$this->set("userInfo", $userInfo);

			if (isset ($configDetails['Configuration']['authorize_amount']) && $configDetails['Configuration']['authorize_amount'] != '0.00') {
				$paymentType = urlencode('Authorization'); // Authorization or 'Sale'
				$firstName = urlencode($userAddress['User']['first_name']);
				$lastName = urlencode($userAddress['User']['last_name']);
				$creditCardType = urlencode($userAddress['User']['card_type']);
				$creditCardNumber = urlencode($userAddress['User']['card_number']); //$userInfo['PayAsYouGoOrder']['card_number']
				$expDateMonth = $userAddress['User']['expiration_card_month'];
				// Month must be padded with leading zero
				$padDateMonth = urlencode(str_pad($expDateMonth, 2, '0', STR_PAD_LEFT));

				$expDateYear = urlencode($userAddress['User']['expiration_card_year']); //$userInfo['PayAsYouGoOrder']['expiration_card_year']
				$cvv2Number = urlencode($userAddress['User']['card_number_cvv']); //$userInfo['PayAsYouGoOrder']['card_number_cvv']
				$address1 = urlencode($userAddress['User']['billing_address']); //$userInfo['PayAsYouGoOrder']['billing_address']
				$address2 = "";
				$city = urlencode($userAddress['User']['billing_city']); //$userInfo['PayAsYouGoOrder']['billing_city']
				$state = urlencode('test state'); //$userInfo['PayAsYouGoOrder']['expiration_card_month']
				$zip = urlencode($userAddress['User']['billing_zip']); //$userInfo['PayAsYouGoOrder']['billing_zip']
				$country = urlencode('US'); // US or other valid country code
				$amount = urlencode($configDetails['Configuration']['authorize_amount']); //$userInfo['PayAsYouGoOrder']['expiration_card_month']
				$currencyID = urlencode('USD'); // or other currency ('GBP', 'EUR', 'JPY', 'CAD', 'AUD')

				// Add request-specific fields to the request string.
				$nvpStr = "&PAYMENTACTION=$paymentType&AMT=$amount&CREDITCARDTYPE=$creditCardType&ACCT=$creditCardNumber" .
				"&EXPDATE=$padDateMonth$expDateYear&CVV2=$cvv2Number&FIRSTNAME=$firstName&LASTNAME=$lastName" .
				"&STREET=$address1&CITY=$city&STATE=$state&ZIP=$zip&COUNTRYCODE=$country&CURRENCYCODE=$currencyID";
//echo '<pre>';print_r($nvpStr);exit;
				$httpParsedResponseAr = $this->Common->PPHttpPostDoAuth('DoDirectPayment', $nvpStr, $environment);

//echo "<pre>";print_r($httpParsedResponseAr);exit;
				$authorizationID = $httpParsedResponseAr['TRANSACTIONID'];
                        } //end if amount not equal to zero

                        /*by deepshikha*/

                        if("SUCCESS" == strtoupper($httpParsedResponseAr["ACK"]) || "SUCCESSWITHWARNING" == strtoupper($httpParsedResponseAr["ACK"])) {
                            $query_update = "UPDATE orders_pay_as_you_go_users SET payment_status='Confirm',status='1',transaction_id='" . $authorizationID . "' WHERE order_id = '" . $order_id . "'";
                            mysql_query($query_update) or die(mysql_error());


                            $this->Order->sendGenerateOrderEmailToAdmin($userAddress["User"]["email_address"], $order_id);

                          /*by deepshikha for sending sms if notification type is sms or email if notification type is email*/
                            if($userAddress["User"]["notify_by"] == 'Sms'){

                                $ph = explode('-', $userAddress['User']['phone']);
                                $phone = $ph[0].$ph[1].$ph[2];

                                $this->Order->sendSms($phone, $order_id, $userAddress["User"]["first_name"]);
                            }else if($userAddress["User"]["notify_by"] == 'Email'){
                                $this->Order->sendGenerateOrderEmail($userAddress["User"]["email_address"], $order_id);
                            }
                          /* end by deepshikha*/

                            //echo "<pre>";pr($httpParsedResponseArCapture);exit;

                            $this->Session->write("message", "Your order has been placed.  You just saved a few hours of work with a few clicks of a mouse!");
                        }else{

                            $query_delete = "DELETE from orders_pay_as_you_go_users WHERE order_id = '" . $order_id . "'";
                            mysql_query($query_delete) or die(mysql_error());

                            $this->Session->write("message", "This transaction cannot be processed. Please update your credit card information!");
                            $this->redirect('/orders/pay_as_you_go');
                        }
		}
	} //end function payment()


	function completeorder() {

        //echo "<pre>";print_r($_SESSION['order_sumry']);exit;
        
		$this->layout = "client";
		$this->set('active', "");
		$this->userLoginCheck();
		$errorMessage = "";

                $user_detail = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			)
		));

                // added by devendra 20120405

                if(empty ($user_detail['User']['address']) || empty ($user_detail['User']['city']) || empty ($user_detail['User']['state']) || empty ($user_detail['User']['zip']))
                {
                    $this->Session->write('message',__('Your delivery information is not complete, Kindly fill your delivery info.',true));
                    $this->redirect('/users/account_step2');
                }

		$paymentstatusinfo = $this->ReguserOrder->find("first", array (
			"conditions" => array (
				"ReguserOrder.user_id = " . $this->Session->read('user_id'),
				"ReguserOrder.payment_status = 'Confirm'",
				"ReguserOrder.status = '1'"
			),
			'order' => 'ReguserOrder.id DESC',
			"limit" => "1"
		));
		$this->set('paymentstatusinfo', $paymentstatusinfo);

		$this->Order->save($_SESSION['order_sumry']);

		$orderid = $this->Order->id;

		$this->Session->delete('order_sumry'); //deletes all data from session
		//to generate a unique order number
		global $cardno;
		$form_order_id = $cardno . str_pad($orderid, 5, "0", STR_PAD_LEFT);
		$this->data['Order']['id'] = $orderid;
		$this->data['Order']['order_no'] = $form_order_id;
		$orderNoArray = array ();
		$orderNoArray['Order']['id'] = $this->data['Order']['id'];
		$orderNoArray['Order']['order_no'] = $this->data['Order']['order_no'];

		$this->Order->save($orderNoArray);

		$this->data['OrdersSubscribedPlansUser']['order_id'] = $orderid;
		$this->data['OrdersSubscribedPlansUser']['plan_id'] = $paymentstatusinfo['ReguserOrder']['id'];
		$this->data['OrdersSubscribedPlansUser']['status'] = '1';
		$this->OrdersSubscribedPlansUser->save($this->data);

		$userAddress = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			)
		));
		$this->set("userAddress", $userAddress);

		$maximum_usage = $paymentstatusinfo['ReguserOrder']['total_usage'];
		$this->set('maximum_usage', $maximum_usage);

		$query_orderinfo = "SELECT order_id, plan_id, SUM(total_weight) FROM orders_subscribed_plans_users WHERE plan_id = '" . $paymentstatusinfo['ReguserOrder']['id'] . "' GROUP BY plan_id";
		$result_orderinfo = mysql_query($query_orderinfo) or die(mysql_error());
		$row_orderinfo = mysql_fetch_assoc($result_orderinfo);

		if (isset ($orderid)) {
			$userInfo = $this->Order->find("first", array (
				"conditions" => array (
					"Order.user_id = " . $this->Session->read('user_id'),
					"Order.id = " . $orderid
				)
			));
			$this->set("userInfo", $userInfo);

			// added by devendra 20120405
                        // $this->ReguserOrder->query("UPDATE reguser_orders SET used_usage = '" . $paymentstatusinfo['ReguserOrder']['used_usage'] . "' + '" . $row_orderinfo['SUM(total_weight)'] . "' WHERE id = '" . $paymentstatusinfo['ReguserOrder']['id'] . "'");

			$this->Order->sendGenerateOrderEmail($userAddress["User"]["email_address"], $orderid);
                        $this->Order->sendGenerateOrderEmailToAdmin($userAddress["User"]["email_address"], $orderid);

			$this->Session->write("message", "Your order has been placed.  You just saved a few hours of work with a few clicks of a mouse!");
		}

	} //end function completeorder()



	function vieworderdetail($orderid = null) {
		$this->layout = "client";
		$this->userLoginCheck();
		$userorderDetails = $this->Order->find("first", array (
			"conditions" => array (
				"Order.id = " . $orderid
			)
		));
		$this->set("userorderDetails", $userorderDetails);

		$userAddress = $this->User->find("first", array (
			"conditions" => array (
				"User.id = " . $this->Session->read('user_id')
			),
			"fields" => array (
				"User.id",
				"User.address"
			)
		));
		$this->set("userAddress", $userAddress);

                $ordereditemInfo = $this->OrderItem->find("all", array ("conditions" => array ("OrderItem.order_id = " . $orderid)));
                $this->set("ordereditemInfo", $ordereditemInfo);
	} //end function vieworderdetail()

	/*paging for my orders*/

	function myorder() {
		$this->layout = "client";
		$this->set("title_for_layout", "My Orders");

		$msgString = '';

		$condition = array ();
		$condition[] = "Order.user_id = " . $this->Session->read('user_id');
		$separator = array ();
		$urlSeparator = array ();

		$separator = implode("/", $separator);

		if (!empty ($this->passedArgs)) {
			if (isset ($this->passedArgs["page"])) {
				$urlSeparator[] = 'page:' . $this->passedArgs["page"];
			}
			if (isset ($this->passedArgs["sort"])) {
				$urlSeparator[] = 'sort:' . $this->passedArgs["sort"];
			}
			if (isset ($this->passedArgs["direction"])) {
				$urlSeparator[] = 'direction:' . $this->passedArgs["direction"];
			}
		}

		$urlSeparator = implode("/", $urlSeparator);

		$this->set('separator', $separator);
		$this->set('urlSeparator', $urlSeparator);

		$this->paginate['Order'] = array (
			'order' => array (
				'Order.id' => 'DESC'
			),
			'limit' => '10'
		);
		$this->set('userorderInfo', $this->paginate('Order', $condition));

	} //end function searchzip()

	function test() {
		$this->layout = "client_inner";

		$deliveryInfo1 = $this->WeighProduct->find("all", array ("conditions" => array ("WeighProduct.status= '1'"),'order' => 'WeighProduct.product_name ASC',"fields" => array ("WeighProduct.id","WeighProduct.product_name","WeighProduct.product_weight")));
		$this->set("deliveryInfo1", $deliveryInfo1);
		//echo '<pre>';print_r($this->data);exit;

	}


        function deleteitems($id = NULL, $order_id = NULL) {
		if ($id > 0) {
                        $this->OrderItem->id = $id;
			$itemInfo = $this->OrderItem->read();
                        $this->OrdersPayAsYouGoUser->query("UPDATE orders_pay_as_you_go_users SET total_weight = '" . $itemInfo['OrdersPayAsYouGoUser']['total_weight'] . "' - '" . $itemInfo['OrderItem']['total_weight'] . "' WHERE order_id = '" . $order_id . "'");
                        //echo '<pre>';print_r($itemInfo);exit;
			$this->OrderItem->delete($id);
			$this->viewPath = 'elements' . DS . 'admin';
			$this->Session->write('message', 'Item deleted successfully.');
			$this->render('blank_delete');
			$this->redirect('/orders/pay_as_you_go/'.$order_id);
		}
	} //end of admin_deleteUser


        function admin_captureAmount($order_id = null){
				
            $this->Order->id = $order_id;
            $orderInfo = $this->Order->read();

            $userInfo = $this->User->find("first", array ("conditions" => array ("User.id = " . $orderInfo['Order']['user_id']),null));

            $configDetails = $this->Configuration->find("first", array (
				"conditions" => "Configuration.id='1'", null));

		if ($configDetails['Configuration']['payment_mode'] == "sandbox") {
			$environment = "sandbox";
		} else {
			$environment = "";
		}

                $this->Session->write("message", "Amount captured successfully");
                $this->redirect('/admin/orders/editOrders/'.$order_id);

                /*
                if (isset($orderInfo) && $orderInfo['OrdersPayAsYouGoUser']['amount_captured_status']== 'not captured') {
								

				$paymentType = urlencode('Sale'); // Authorization or 'Sale'

				$authorizationID = $orderInfo['OrdersPayAsYouGoUser']['transaction_id'];


                                if(($orderInfo['Order']['order_total'] >= $configDetails['Configuration']['authorize_amount']) && $orderInfo['Order']['discount_coupon_code']==''){ //echo 'if not coupon n greater';exit;
                                    $amount = urlencode($configDetails['Configuration']['authorize_amount']);
                                    $remaining_amount = $orderInfo['Order']['order_total'] - $configDetails['Configuration']['authorize_amount'];
                                }

                                else if(($orderInfo['Order']['order_total'] < $configDetails['Configuration']['authorize_amount']) && $orderInfo['Order']['discount_coupon_code']==''){ //echo 'if not coupon n less';exit;
                                    $amount = urlencode($orderInfo['Order']['order_total']);
                                    $remaining_amount = '0.00';
                                }

                                else if($orderInfo['Order']['discount_coupon_code']!='' && ($orderInfo['Order']['discounted_order_amount'] >= $configDetails['Configuration']['authorize_amount'])){ //echo 'if coupon n greater';exit;
                                    $amount = urlencode($configDetails['Configuration']['authorize_amount']);
                                    $remaining_amount = $orderInfo['Order']['discounted_order_amount'] - $configDetails['Configuration']['authorize_amount'];
                                }

                                else if($orderInfo['Order']['discount_coupon_code']!='' && ($orderInfo['Order']['discounted_order_amount'] < $configDetails['Configuration']['authorize_amount'])){ //echo 'if coupon n less';exit;

                                	if((($orderInfo['Order']['discounted_order_amount']) + ($orderInfo['Order']['drycleaning_amount'])) >= $configDetails['Configuration']['authorize_amount']){ //echo 'greater';exit;
										$amount = urlencode($configDetails['Configuration']['authorize_amount']);
										$remaining_amount = (($orderInfo['Order']['drycleaning_amount']) + ($orderInfo['Order']['discounted_order_amount']))- $configDetails['Configuration']['authorize_amount'];
									}

									if((($orderInfo['Order']['discounted_order_amount']) + ($orderInfo['Order']['drycleaning_amount'])) < $configDetails['Configuration']['authorize_amount']){ //echo 'less';exit;
										$amount = urlencode(($orderInfo['Order']['discounted_order_amount']) + ($orderInfo['Order']['drycleaning_amount']));
										$remaining_amount = '0.00';
									}

                                }
//                              else{
//                                    $amount = urlencode($orderInfo['Order']['discounted_order_amount']);
//                                    $remaining_amount = '0.00';
//                              }


				//$currency = urlencode('USD'); // or other currency ('GBP', 'EUR', 'JPY', 'CAD', 'AUD')
				//$completeCodeType = urlencode('Complete'); // or 'NotComplete'
				//$invoiceID = urlencode('');
				//$note = urlencode('');
				//$nvpStrCap = "&AUTHORIZATIONID=$authorizationID&AMT=$amount&COMPLETETYPE=$completeCodeType&CURRENCYCODE=$currency&NOTE=$note";				
				// This will capture the exact amount from the authorize amount
								
				//$httpParsedResponseArCapture = $this->Common->capture('DoCapture', $nvpStrCap, $environment);
				
						
				if($remaining_amount!='0.00'){	
									
					$userAddress = $this->User->find("first", array (
						"conditions" => array (
							"User.id = " . $orderInfo['Order']['user_id']
						)
					));
						
						
						$tran=$this;
						if ($configDetails['Configuration']['payment_mode'] == "sandbox") {
							//$environment = "sandbox";
							$tran->usesandbox=true;    
						} else {
							//$environment = "";
							$tran->usesandbox=true;    
						}					
	
						//$tran->key="JQ2ES5j5P9xXNTjR5vFpMI0DDT5vtaJ8";  // This is live key
						//$tran->pin="BTML";
						
						//$tran->key="SSn41U99mGh3siG73kQ1o16QsmjRIhSm";    // This is test key
						//$tran->pin="1234";
						
						$tran->key="_rXxx6Q6h1vW81bH9v55IKa6OrJMP7La";  // This is test key
						$tran->pin="1234";										
						
						$expMonth = $userAddress['User']['expiration_card_month'];
						$expYear = $userAddress['User']['expiration_card_year'];
						
						$tran->card=urlencode($userAddress['User']['card_number']);
						$tran->exp=urlencode(str_pad($expMonth, 2, '0', STR_PAD_LEFT)).$expYear;			
						$tran->amount=urlencode($remaining_amount);	
						$tran->invoice="1234";   		
						$tran->cardholder= urlencode($userAddress['User']['first_name'])." ".urlencode($userAddress['User']['last_name']);
						$tran->street=urlencode($userAddress['User']['billing_address']);	
						$tran->zip=urlencode($userAddress['User']['billing_zip']);			
						$tran->description="Online Order";	
						$tran->cvv2=urlencode($userAddress['User']['card_number_cvv']);								
						flush();
						
							if($tran->Process()) {								
									$authorizationID = $tran->cctransid;
	
								$query_update_payasgo = "UPDATE orders_pay_as_you_go_users SET amount_captured_status = 'captured', transaction_id='".$authorizationID."' WHERE order_id = '" . $order_id . "'";
								
									mysql_query($query_update_payasgo) or die(mysql_error());
	
									$query_update_orders = "UPDATE orders SET captured_amount = '".$amount."', remaining_amount = '".$remaining_amount."', remaining_amount_captured='Yes' WHERE id = '" . $order_id . "'";
									mysql_query($query_update_orders) or die(mysql_error());
	
	
	
									//$this->Order->sendAmountCapturedEmail($userInfo['User']['email_address'],$orderInfo['Order']['order_no'], $amount, $remaining_amount);
									$to = $userAddress['User']['email_address'];
									$subject = "Payment Captured for BTM Laundry Order";
									$message .= "$".$amount." are captured from your account. ";
									//echo $message;exit;
									if($remaining_amount!='0.00'){
										$message .= " $".$remaining_amount." is remaining amount, you will have to pay at delivery time.";
									}
									$headers .= "From: ".SITE_TITLE." <info@".SITE_TITLE_MAIL.".com>\r\n";
	
									mail($to,$subject,$message,$headers);
	
									$this->Session->write("message", "The amount is captured!");
									$this->redirect('/admin/orders/editOrders/'.$order_id);
							}else{
								$this->Session->write("message", "Unable to capture amout please check payment details");								
                                $this->redirect('/admin/orders/editOrders/'.$order_id);
							}
						}
								
                   }

                    else{
                                $this->Session->write("message", "Amount captured successfully");
                                //$this->Session->write("message", "The amount is already captured and can not be captured again!");
								
                                $this->redirect('/admin/orders/editOrders/'.$order_id);
                    }
                    */
        
		} //end function admin_captureAmount($order_id)


        function admin_captureAmount_backup($order_id = null){
		
            $this->Order->id = $order_id;
            $orderInfo = $this->Order->read();

            $userInfo = $this->User->find("first", array ("conditions" => array ("User.id = " . $orderInfo['Order']['user_id']),null));

            $configDetails = $this->Configuration->find("first", array (
				"conditions" => "Configuration.id='1'", null));

		if ($configDetails['Configuration']['payment_mode'] == "sandbox") {
			$environment = "sandbox";
		} else {
			$environment = "";
		}

                if (isset($orderInfo) && $orderInfo['OrdersPayAsYouGoUser']['amount_captured_status']== 'not captured') {

				$paymentType = urlencode('Sale'); // Authorization or 'Sale'

				$authorizationID = $orderInfo['OrdersPayAsYouGoUser']['transaction_id'];

                                if(($orderInfo['Order']['order_total'] >= $configDetails['Configuration']['authorize_amount']) && $orderInfo['Order']['discount_coupon_code']==''){ //echo 'if not coupon n greater';exit;
                                    $amount = urlencode($configDetails['Configuration']['authorize_amount']);
                                    $remaining_amount = $orderInfo['Order']['order_total'] - $configDetails['Configuration']['authorize_amount'];
                                }

                                else if(($orderInfo['Order']['order_total'] < $configDetails['Configuration']['authorize_amount']) && $orderInfo['Order']['discount_coupon_code']==''){ //echo 'if not coupon n less';exit;
                                    $amount = urlencode($orderInfo['Order']['order_total']);
                                    $remaining_amount = '0.00';
                                }

                                else if($orderInfo['Order']['discount_coupon_code']!='' && ($orderInfo['Order']['discounted_order_amount'] >= $configDetails['Configuration']['authorize_amount'])){ //echo 'if coupon n greater';exit;
                                    $amount = urlencode($configDetails['Configuration']['authorize_amount']);
                                    $remaining_amount = $orderInfo['Order']['discounted_order_amount'] - $configDetails['Configuration']['authorize_amount'];
                                }

                                else if($orderInfo['Order']['discount_coupon_code']!='' && ($orderInfo['Order']['discounted_order_amount'] < $configDetails['Configuration']['authorize_amount'])){ //echo 'if coupon n less';exit;

                                	if((($orderInfo['Order']['discounted_order_amount']) + ($orderInfo['Order']['drycleaning_amount'])) >= $configDetails['Configuration']['authorize_amount']){ //echo 'greater';exit;
										$amount = urlencode($configDetails['Configuration']['authorize_amount']);
										$remaining_amount = (($orderInfo['Order']['drycleaning_amount']) + ($orderInfo['Order']['discounted_order_amount']))- $configDetails['Configuration']['authorize_amount'];
									}

									if((($orderInfo['Order']['discounted_order_amount']) + ($orderInfo['Order']['drycleaning_amount'])) < $configDetails['Configuration']['authorize_amount']){ //echo 'less';exit;
										$amount = urlencode(($orderInfo['Order']['discounted_order_amount']) + ($orderInfo['Order']['drycleaning_amount']));
										$remaining_amount = '0.00';
									}

                                }
//                              else{
//                                    $amount = urlencode($orderInfo['Order']['discounted_order_amount']);
//                                    $remaining_amount = '0.00';
//                              }

				$currency = urlencode('USD'); // or other currency ('GBP', 'EUR', 'JPY', 'CAD', 'AUD')
				$completeCodeType = urlencode('Complete'); // or 'NotComplete'
				$invoiceID = urlencode('');
				$note = urlencode('');
				$nvpStrCap = "&AUTHORIZATIONID=$authorizationID&AMT=$amount&COMPLETETYPE=$completeCodeType&CURRENCYCODE=$currency&NOTE=$note";
				//echo '<pre>';print_r($nvpStrCap);exit;
				// This will capture the exact amount from the authorize amount
				$httpParsedResponseArCapture = $this->Common->capture('DoCapture', $nvpStrCap, $environment);

                                $query_update_payasgo = "UPDATE orders_pay_as_you_go_users SET amount_captured_status = 'captured' WHERE id = '" . $order_id . "'";
                                mysql_query($query_update_payasgo) or die(mysql_error());

                                $query_update_orders = "UPDATE orders SET captured_amount = '".$amount."', remaining_amount = '".$remaining_amount."' WHERE id = '" . $order_id . "'";
                                mysql_query($query_update_orders) or die(mysql_error());


                                /*code for send mail to user about
                                 * the info of payment capturization
                                 */

                                //$this->Order->sendAmountCapturedEmail($userInfo['User']['email_address'],$orderInfo['Order']['order_no'], $amount, $remaining_amount);
                                $to = $userInfo['User']['email_address'];
                                $subject = "Payment Captured for BTM Laundry Order";
                                $message .= "$".$amount." are captured from your account. ";
                                //echo $message;exit;
                                if($remaining_amount!='0.00'){
                                    $message .= " $".$remaining_amount." is remaining amount, you will have to pay at delivery time.";
                                }
                                $headers .= "From: ".SITE_TITLE." <info@".SITE_TITLE_MAIL.".com>\r\n";

                                mail($to,$subject,$message,$headers);

                                $this->Session->write("message", "The amount is captured!");
                                $this->redirect('/admin/orders/editOrders/'.$order_id);
                    } //end if amount not equal to zero


                    else{
                                $this->Session->write("message", "The amount is already captured and can not be captured again!");
                                $this->redirect('/admin/orders/editOrders/'.$order_id);
                    }

        
		} //end function admin_captureAmount($order_id)



        function weight_calc() {
            $this->layout="clientpopup";
            $this->set("title", "Weight Calculator");

            $deliveryInfo1 = $this->WeighProduct->find("all", array ("conditions" => array ("WeighProduct.status= '1'"),'order' => 'WeighProduct.product_name ASC',"fields" => array ("WeighProduct.id","WeighProduct.product_name","WeighProduct.product_weight")));
            $this->set("deliveryInfo1", $deliveryInfo1);
        }
		
		function admin_login_user_by_admin($UserID=NULL){
			
			$UserCheck = $this->User->find("first",array("conditions"=>array("User.id = '".$UserID."'")));
			$this->Session->write("user_id",$UserCheck['User']['id']);
			$this->Session->write("user_email",$UserCheck['User']['email_address']);
			$this->Session->write("user_name",$UserCheck['User']['first_name']);
			$this->Session->write('user_inserted_id',$UserCheck['User']['id']);
			$this->redirect('/users/account_step1');
			

		}
		
        function admin_exportOrderTodays($id=NULL){

                $this->layout="default";
		
                $contents   =   "";
					if($id == "csv"){
					
                
				 $currentorddate = date('Y-m-d');
                 $contactInfo = $this->Order->find("all",array("conditions"=>"Order.delivery_date='".$currentorddate."'"));

				$fnamedate = date("Ymd");			
				header('Content-Type: application/excel');
				header('Content-Disposition: attachment; filename="order_'.$fnamedate.'.csv"');


				$fp = fopen('php://output', 'w');
				$i = 0;
				foreach ( $contactInfo as $line ) {  
				
				   
					if($i==0){
						$TemoArray = array("Customer Name","Address","Phone Number","SPOT","Laundry/DC","Pick-up Location","Drop-off Location","Order For","Order Notes"); 
						fputcsv($fp,$TemoArray);
					}
					
					$queryuserinfo = "select first_name, last_name, address, phone, spot from users where id='".$line['Order']['user_id']."'";
					$resultuserinfo = mysql_query($queryuserinfo);
					$rowuserinfo = mysql_fetch_assoc($resultuserinfo);
						
					$TemoArray = array($rowuserinfo['first_name']." ".$rowuserinfo['last_name'],$rowuserinfo['address'],$rowuserinfo['phone'],$rowuserinfo['spot'],$line['Order']['order_plan_type'],$line['Order']['pickup_location'],$line['Order']['delivery_location'],$line['Order']['pickup_notes'],$line['Order']['order_notes']); 
					fputcsv($fp,$TemoArray);
				   // fputcsv($fp, $line);
				   $i++; 
					
				}
				fclose($fp);
				exit;

		} //end if($id == "csv")

	} //end function
		

}
?>
